from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.server_stats_videos_redundancy_item import (
        ServerStatsVideosRedundancyItem,
    )


T = TypeVar("T", bound="ServerStats")


@_attrs_define
class ServerStats:
    """Attributes:
    total_users (Union[Unset, float]):
    total_daily_active_users (Union[Unset, float]):
    total_weekly_active_users (Union[Unset, float]):
    total_monthly_active_users (Union[Unset, float]):
    total_moderators (Union[Unset, float]): **PeerTube >=6.1** Value is null if the admin disabled total moderators
        stats
    total_admins (Union[Unset, float]): **PeerTube >=6.1** Value is null if the admin disabled total admins stats
    total_local_videos (Union[Unset, float]):
    total_local_video_views (Union[Unset, float]): Total video views made on the instance
    total_local_video_comments (Union[Unset, float]): Total comments made by local users
    total_local_video_files_size (Union[Unset, float]):
    total_videos (Union[Unset, float]):
    total_video_comments (Union[Unset, float]):
    total_local_video_channels (Union[Unset, float]):
    total_local_daily_active_video_channels (Union[Unset, float]):
    total_local_weekly_active_video_channels (Union[Unset, float]):
    total_local_monthly_active_video_channels (Union[Unset, float]):
    total_local_playlists (Union[Unset, float]):
    total_instance_followers (Union[Unset, float]):
    total_instance_following (Union[Unset, float]):
    videos_redundancy (Union[Unset, list['ServerStatsVideosRedundancyItem']]):
    total_activity_pub_messages_processed (Union[Unset, float]):
    total_activity_pub_messages_successes (Union[Unset, float]):
    total_activity_pub_messages_errors (Union[Unset, float]):
    activity_pub_messages_processed_per_second (Union[Unset, float]):
    total_activity_pub_messages_waiting (Union[Unset, float]):
    average_registration_request_response_time_ms (Union[Unset, float]): **PeerTube >=6.1** Value is null if the
        admin disabled registration requests stats
    total_registration_requests_processed (Union[Unset, float]): **PeerTube >=6.1** Value is null if the admin
        disabled registration requests stats
    total_registration_requests (Union[Unset, float]): **PeerTube >=6.1** Value is null if the admin disabled
        registration requests stats
    average_abuse_response_time_ms (Union[Unset, float]): **PeerTube >=6.1** Value is null if the admin disabled
        abuses stats
    total_abuses_processed (Union[Unset, float]): **PeerTube >=6.1** Value is null if the admin disabled abuses
        stats
    total_abuses (Union[Unset, float]): **PeerTube >=6.1** Value is null if the admin disabled abuses stats
    """

    total_users: Unset | float = UNSET
    total_daily_active_users: Unset | float = UNSET
    total_weekly_active_users: Unset | float = UNSET
    total_monthly_active_users: Unset | float = UNSET
    total_moderators: Unset | float = UNSET
    total_admins: Unset | float = UNSET
    total_local_videos: Unset | float = UNSET
    total_local_video_views: Unset | float = UNSET
    total_local_video_comments: Unset | float = UNSET
    total_local_video_files_size: Unset | float = UNSET
    total_videos: Unset | float = UNSET
    total_video_comments: Unset | float = UNSET
    total_local_video_channels: Unset | float = UNSET
    total_local_daily_active_video_channels: Unset | float = UNSET
    total_local_weekly_active_video_channels: Unset | float = UNSET
    total_local_monthly_active_video_channels: Unset | float = UNSET
    total_local_playlists: Unset | float = UNSET
    total_instance_followers: Unset | float = UNSET
    total_instance_following: Unset | float = UNSET
    videos_redundancy: Unset | list["ServerStatsVideosRedundancyItem"] = UNSET
    total_activity_pub_messages_processed: Unset | float = UNSET
    total_activity_pub_messages_successes: Unset | float = UNSET
    total_activity_pub_messages_errors: Unset | float = UNSET
    activity_pub_messages_processed_per_second: Unset | float = UNSET
    total_activity_pub_messages_waiting: Unset | float = UNSET
    average_registration_request_response_time_ms: Unset | float = UNSET
    total_registration_requests_processed: Unset | float = UNSET
    total_registration_requests: Unset | float = UNSET
    average_abuse_response_time_ms: Unset | float = UNSET
    total_abuses_processed: Unset | float = UNSET
    total_abuses: Unset | float = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        total_users = self.total_users

        total_daily_active_users = self.total_daily_active_users

        total_weekly_active_users = self.total_weekly_active_users

        total_monthly_active_users = self.total_monthly_active_users

        total_moderators = self.total_moderators

        total_admins = self.total_admins

        total_local_videos = self.total_local_videos

        total_local_video_views = self.total_local_video_views

        total_local_video_comments = self.total_local_video_comments

        total_local_video_files_size = self.total_local_video_files_size

        total_videos = self.total_videos

        total_video_comments = self.total_video_comments

        total_local_video_channels = self.total_local_video_channels

        total_local_daily_active_video_channels = (
            self.total_local_daily_active_video_channels
        )

        total_local_weekly_active_video_channels = (
            self.total_local_weekly_active_video_channels
        )

        total_local_monthly_active_video_channels = (
            self.total_local_monthly_active_video_channels
        )

        total_local_playlists = self.total_local_playlists

        total_instance_followers = self.total_instance_followers

        total_instance_following = self.total_instance_following

        videos_redundancy: Unset | list[dict[str, Any]] = UNSET
        if not isinstance(self.videos_redundancy, Unset):
            videos_redundancy = []
            for videos_redundancy_item_data in self.videos_redundancy:
                videos_redundancy_item = videos_redundancy_item_data.to_dict()
                videos_redundancy.append(videos_redundancy_item)

        total_activity_pub_messages_processed = (
            self.total_activity_pub_messages_processed
        )

        total_activity_pub_messages_successes = (
            self.total_activity_pub_messages_successes
        )

        total_activity_pub_messages_errors = self.total_activity_pub_messages_errors

        activity_pub_messages_processed_per_second = (
            self.activity_pub_messages_processed_per_second
        )

        total_activity_pub_messages_waiting = self.total_activity_pub_messages_waiting

        average_registration_request_response_time_ms = (
            self.average_registration_request_response_time_ms
        )

        total_registration_requests_processed = (
            self.total_registration_requests_processed
        )

        total_registration_requests = self.total_registration_requests

        average_abuse_response_time_ms = self.average_abuse_response_time_ms

        total_abuses_processed = self.total_abuses_processed

        total_abuses = self.total_abuses

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if total_users is not UNSET:
            field_dict["totalUsers"] = total_users
        if total_daily_active_users is not UNSET:
            field_dict["totalDailyActiveUsers"] = total_daily_active_users
        if total_weekly_active_users is not UNSET:
            field_dict["totalWeeklyActiveUsers"] = total_weekly_active_users
        if total_monthly_active_users is not UNSET:
            field_dict["totalMonthlyActiveUsers"] = total_monthly_active_users
        if total_moderators is not UNSET:
            field_dict["totalModerators"] = total_moderators
        if total_admins is not UNSET:
            field_dict["totalAdmins"] = total_admins
        if total_local_videos is not UNSET:
            field_dict["totalLocalVideos"] = total_local_videos
        if total_local_video_views is not UNSET:
            field_dict["totalLocalVideoViews"] = total_local_video_views
        if total_local_video_comments is not UNSET:
            field_dict["totalLocalVideoComments"] = total_local_video_comments
        if total_local_video_files_size is not UNSET:
            field_dict["totalLocalVideoFilesSize"] = total_local_video_files_size
        if total_videos is not UNSET:
            field_dict["totalVideos"] = total_videos
        if total_video_comments is not UNSET:
            field_dict["totalVideoComments"] = total_video_comments
        if total_local_video_channels is not UNSET:
            field_dict["totalLocalVideoChannels"] = total_local_video_channels
        if total_local_daily_active_video_channels is not UNSET:
            field_dict["totalLocalDailyActiveVideoChannels"] = (
                total_local_daily_active_video_channels
            )
        if total_local_weekly_active_video_channels is not UNSET:
            field_dict["totalLocalWeeklyActiveVideoChannels"] = (
                total_local_weekly_active_video_channels
            )
        if total_local_monthly_active_video_channels is not UNSET:
            field_dict["totalLocalMonthlyActiveVideoChannels"] = (
                total_local_monthly_active_video_channels
            )
        if total_local_playlists is not UNSET:
            field_dict["totalLocalPlaylists"] = total_local_playlists
        if total_instance_followers is not UNSET:
            field_dict["totalInstanceFollowers"] = total_instance_followers
        if total_instance_following is not UNSET:
            field_dict["totalInstanceFollowing"] = total_instance_following
        if videos_redundancy is not UNSET:
            field_dict["videosRedundancy"] = videos_redundancy
        if total_activity_pub_messages_processed is not UNSET:
            field_dict["totalActivityPubMessagesProcessed"] = (
                total_activity_pub_messages_processed
            )
        if total_activity_pub_messages_successes is not UNSET:
            field_dict["totalActivityPubMessagesSuccesses"] = (
                total_activity_pub_messages_successes
            )
        if total_activity_pub_messages_errors is not UNSET:
            field_dict["totalActivityPubMessagesErrors"] = (
                total_activity_pub_messages_errors
            )
        if activity_pub_messages_processed_per_second is not UNSET:
            field_dict["activityPubMessagesProcessedPerSecond"] = (
                activity_pub_messages_processed_per_second
            )
        if total_activity_pub_messages_waiting is not UNSET:
            field_dict["totalActivityPubMessagesWaiting"] = (
                total_activity_pub_messages_waiting
            )
        if average_registration_request_response_time_ms is not UNSET:
            field_dict["averageRegistrationRequestResponseTimeMs"] = (
                average_registration_request_response_time_ms
            )
        if total_registration_requests_processed is not UNSET:
            field_dict["totalRegistrationRequestsProcessed"] = (
                total_registration_requests_processed
            )
        if total_registration_requests is not UNSET:
            field_dict["totalRegistrationRequests"] = total_registration_requests
        if average_abuse_response_time_ms is not UNSET:
            field_dict["averageAbuseResponseTimeMs"] = average_abuse_response_time_ms
        if total_abuses_processed is not UNSET:
            field_dict["totalAbusesProcessed"] = total_abuses_processed
        if total_abuses is not UNSET:
            field_dict["totalAbuses"] = total_abuses

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.server_stats_videos_redundancy_item import (
            ServerStatsVideosRedundancyItem,
        )

        d = dict(src_dict)
        total_users = d.pop("totalUsers", UNSET)

        total_daily_active_users = d.pop("totalDailyActiveUsers", UNSET)

        total_weekly_active_users = d.pop("totalWeeklyActiveUsers", UNSET)

        total_monthly_active_users = d.pop("totalMonthlyActiveUsers", UNSET)

        total_moderators = d.pop("totalModerators", UNSET)

        total_admins = d.pop("totalAdmins", UNSET)

        total_local_videos = d.pop("totalLocalVideos", UNSET)

        total_local_video_views = d.pop("totalLocalVideoViews", UNSET)

        total_local_video_comments = d.pop("totalLocalVideoComments", UNSET)

        total_local_video_files_size = d.pop("totalLocalVideoFilesSize", UNSET)

        total_videos = d.pop("totalVideos", UNSET)

        total_video_comments = d.pop("totalVideoComments", UNSET)

        total_local_video_channels = d.pop("totalLocalVideoChannels", UNSET)

        total_local_daily_active_video_channels = d.pop(
            "totalLocalDailyActiveVideoChannels", UNSET
        )

        total_local_weekly_active_video_channels = d.pop(
            "totalLocalWeeklyActiveVideoChannels", UNSET
        )

        total_local_monthly_active_video_channels = d.pop(
            "totalLocalMonthlyActiveVideoChannels", UNSET
        )

        total_local_playlists = d.pop("totalLocalPlaylists", UNSET)

        total_instance_followers = d.pop("totalInstanceFollowers", UNSET)

        total_instance_following = d.pop("totalInstanceFollowing", UNSET)

        videos_redundancy = []
        _videos_redundancy = d.pop("videosRedundancy", UNSET)
        for videos_redundancy_item_data in _videos_redundancy or []:
            videos_redundancy_item = ServerStatsVideosRedundancyItem.from_dict(
                videos_redundancy_item_data
            )

            videos_redundancy.append(videos_redundancy_item)

        total_activity_pub_messages_processed = d.pop(
            "totalActivityPubMessagesProcessed", UNSET
        )

        total_activity_pub_messages_successes = d.pop(
            "totalActivityPubMessagesSuccesses", UNSET
        )

        total_activity_pub_messages_errors = d.pop(
            "totalActivityPubMessagesErrors", UNSET
        )

        activity_pub_messages_processed_per_second = d.pop(
            "activityPubMessagesProcessedPerSecond", UNSET
        )

        total_activity_pub_messages_waiting = d.pop(
            "totalActivityPubMessagesWaiting", UNSET
        )

        average_registration_request_response_time_ms = d.pop(
            "averageRegistrationRequestResponseTimeMs", UNSET
        )

        total_registration_requests_processed = d.pop(
            "totalRegistrationRequestsProcessed", UNSET
        )

        total_registration_requests = d.pop("totalRegistrationRequests", UNSET)

        average_abuse_response_time_ms = d.pop("averageAbuseResponseTimeMs", UNSET)

        total_abuses_processed = d.pop("totalAbusesProcessed", UNSET)

        total_abuses = d.pop("totalAbuses", UNSET)

        server_stats = cls(
            total_users=total_users,
            total_daily_active_users=total_daily_active_users,
            total_weekly_active_users=total_weekly_active_users,
            total_monthly_active_users=total_monthly_active_users,
            total_moderators=total_moderators,
            total_admins=total_admins,
            total_local_videos=total_local_videos,
            total_local_video_views=total_local_video_views,
            total_local_video_comments=total_local_video_comments,
            total_local_video_files_size=total_local_video_files_size,
            total_videos=total_videos,
            total_video_comments=total_video_comments,
            total_local_video_channels=total_local_video_channels,
            total_local_daily_active_video_channels=total_local_daily_active_video_channels,
            total_local_weekly_active_video_channels=total_local_weekly_active_video_channels,
            total_local_monthly_active_video_channels=total_local_monthly_active_video_channels,
            total_local_playlists=total_local_playlists,
            total_instance_followers=total_instance_followers,
            total_instance_following=total_instance_following,
            videos_redundancy=videos_redundancy,
            total_activity_pub_messages_processed=total_activity_pub_messages_processed,
            total_activity_pub_messages_successes=total_activity_pub_messages_successes,
            total_activity_pub_messages_errors=total_activity_pub_messages_errors,
            activity_pub_messages_processed_per_second=activity_pub_messages_processed_per_second,
            total_activity_pub_messages_waiting=total_activity_pub_messages_waiting,
            average_registration_request_response_time_ms=average_registration_request_response_time_ms,
            total_registration_requests_processed=total_registration_requests_processed,
            total_registration_requests=total_registration_requests,
            average_abuse_response_time_ms=average_abuse_response_time_ms,
            total_abuses_processed=total_abuses_processed,
            total_abuses=total_abuses,
        )

        server_stats.additional_properties = d
        return server_stats

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""Tests for api_accounts_name_video_playlists function."""

from peertube.api.video_playlists.api_accounts_name_video_playlists import sync
from peertube.models.get_api_v1_accounts_name_video_playlists_response_200 import (
    GetApiV1AccountsNameVideoPlaylistsResponse200,
)
from peertube.types import UNSET


def test_api_accounts_name_video_playlists_success(
    httpx_mock, client, sample_playlist_response_data
):
    """Test successful retrieval of account playlists."""
    # Mock HTTP response
    httpx_mock.add_response(
        method="GET",
        url="https://test.peertube.example/api/v1/accounts/test-account/video-playlists?count=15",
        json=sample_playlist_response_data,
        status_code=200,
    )

    # Test the function
    result = sync(
        name="test-account",
        client=client,
        start=UNSET,
        count=15,
        sort=UNSET,
        search=UNSET,
        playlist_type=UNSET,
    )

    # Assert result is the expected model
    expected = GetApiV1AccountsNameVideoPlaylistsResponse200.from_dict(
        sample_playlist_response_data
    )
    assert result == expected



from typing import Any

import httpx

from peertube.api.shared_utils import build_response, parse_response
from peertube.client import AuthenticatedClient, Client
from peertube.types import UNSET, Response, Unset


def _get_kwargs(
    name: str,
    *,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["start"] = start

    params["count"] = count

    params["sort"] = sort
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/api/v1/accounts/{name}/video-channel-syncs",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Any | None:
    return parse_response(client=client, response=response)


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[Any]:
    return build_response(client=client, response=response)


def sync_detailed(
    name: str,
    *,
    client: AuthenticatedClient | Client,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> Response[Any]:
    """List the synchronizations of video channels of an account


    Args:
        name (str):  Example: chocobozzz | chocobozzz@example.org.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        sort (Union[Unset, str]):  Example: -createdAt.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(name=name, start=start, count=count, sort=sort)

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    name: str,
    *,
    client: AuthenticatedClient | Client,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> Any | None:
    """List the synchronizations of video channels of an account


    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Any
    """

    return sync_detailed(
        name=name, client=client, start=start, count=count, sort=sort
    ).parsed


async def asyncio_detailed(
    name: str,
    *,
    client: AuthenticatedClient | Client,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> Response[Any]:
    """List the synchronizations of video channels of an account


    Args:
        name (str):  Example: chocobozzz | chocobozzz@example.org.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        sort (Union[Unset, str]):  Example: -createdAt.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(name=name, start=start, count=count, sort=sort)

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.register_user_channel import RegisterUserChannel


T = TypeVar("T", bound="RegisterUser")


@_attrs_define
class RegisterUser:
    """Attributes:
    username (str): immutable name of the user, used to find or mention its actor Example: chocobozzz.
    password (str):
    email (str): email of the user, used for login or service communications
    display_name (Union[Unset, str]): editable name of the user, displayed in its representations
    channel (Union[Unset, RegisterUserChannel]): channel base information used to create the first channel of the
        user
    """

    username: str
    password: str
    email: str
    display_name: Unset | str = UNSET
    channel: Union[Unset, "RegisterUserChannel"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        username = self.username

        password = self.password

        email = self.email

        display_name = self.display_name

        channel: Unset | dict[str, Any] = UNSET
        if not isinstance(self.channel, Unset):
            channel = self.channel.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "username": username,
                "password": password,
                "email": email,
            }
        )
        if display_name is not UNSET:
            field_dict["displayName"] = display_name
        if channel is not UNSET:
            field_dict["channel"] = channel

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.register_user_channel import RegisterUserChannel

        d = dict(src_dict)
        username = d.pop("username")

        password = d.pop("password")

        email = d.pop("email")

        display_name = d.pop("displayName", UNSET)

        _channel = d.pop("channel", UNSET)
        channel: Unset | RegisterUserChannel
        if isinstance(_channel, Unset):
            channel = UNSET
        else:
            channel = RegisterUserChannel.from_dict(_channel)

        register_user = cls(
            username=username,
            password=password,
            email=email,
            display_name=display_name,
            channel=channel,
        )

        register_user.additional_properties = d
        return register_user

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class FileRedundancyInformationStrategy(str, Enum):
    """FileRedundancyInformationStrategy enumeration."""

    MANUAL = "manual"
    MOST_VIEWS = "most-views"
    RECENTLY_ADDED = "recently-added"
    TRENDING = "trending"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.account_summary import AccountSummary
    from peertube.models.video_channel_summary import VideoChannelSummary
    from peertube.models.video_playlist_privacy_constant import (
        VideoPlaylistPrivacyConstant,
    )
    from peertube.models.video_playlist_type_constant import VideoPlaylistTypeConstant


T = TypeVar("T", bound="VideoPlaylist")


@_attrs_define
class VideoPlaylist:
    """Attributes:
    id (Union[Unset, int]):  Example: 42.
    uuid (Union[Unset, UUID]):  Example: 9c9de5e8-0a1e-484a-b099-e80766180a6d.
    short_uuid (Union[Unset, str]): translation of a uuid v4 with a bigger alphabet to have a shorter uuid Example:
        2y84q2MQUMWPbiEcxNXMgC.
    created_at (Union[Unset, datetime.datetime]):
    updated_at (Union[Unset, datetime.datetime]):
    description (Union[Unset, str]):
    display_name (Union[Unset, str]):
    is_local (Union[Unset, bool]):
    video_length (Union[Unset, int]):
    thumbnail_path (Union[Unset, str]):
    privacy (Union[Unset, VideoPlaylistPrivacyConstant]):
    type_ (Union[Unset, VideoPlaylistTypeConstant]):
    owner_account (Union[Unset, AccountSummary]):
    video_channel (Union[Unset, VideoChannelSummary]):
    video_channel_position (Union[Unset, int]): Position of the playlist in the channel
    """

    id: Unset | int = UNSET
    uuid: Unset | UUID = UNSET
    short_uuid: Unset | str = UNSET
    created_at: Unset | datetime.datetime = UNSET
    updated_at: Unset | datetime.datetime = UNSET
    description: Unset | str = UNSET
    display_name: Unset | str = UNSET
    is_local: Unset | bool = UNSET
    video_length: Unset | int = UNSET
    thumbnail_path: Unset | str = UNSET
    privacy: Union[Unset, "VideoPlaylistPrivacyConstant"] = UNSET
    type_: Union[Unset, "VideoPlaylistTypeConstant"] = UNSET
    owner_account: Union[Unset, "AccountSummary"] = UNSET
    video_channel: Union[Unset, "VideoChannelSummary"] = UNSET
    video_channel_position: Unset | int = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        id = self.id

        uuid: Unset | str = UNSET
        if not isinstance(self.uuid, Unset):
            uuid = str(self.uuid)

        short_uuid = self.short_uuid

        created_at: Unset | str = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Unset | str = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        description = self.description

        display_name = self.display_name

        is_local = self.is_local

        video_length = self.video_length

        thumbnail_path = self.thumbnail_path

        privacy: Unset | dict[str, Any] = UNSET
        if not isinstance(self.privacy, Unset):
            privacy = self.privacy.to_dict()

        type_: Unset | dict[str, Any] = UNSET
        if not isinstance(self.type_, Unset):
            type_ = self.type_.to_dict()

        owner_account: Unset | dict[str, Any] = UNSET
        if not isinstance(self.owner_account, Unset):
            owner_account = self.owner_account.to_dict()

        video_channel: Unset | dict[str, Any] = UNSET
        if not isinstance(self.video_channel, Unset):
            video_channel = self.video_channel.to_dict()

        video_channel_position = self.video_channel_position

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if uuid is not UNSET:
            field_dict["uuid"] = uuid
        if short_uuid is not UNSET:
            field_dict["shortUUID"] = short_uuid
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at
        if description is not UNSET:
            field_dict["description"] = description
        if display_name is not UNSET:
            field_dict["displayName"] = display_name
        if is_local is not UNSET:
            field_dict["isLocal"] = is_local
        if video_length is not UNSET:
            field_dict["videoLength"] = video_length
        if thumbnail_path is not UNSET:
            field_dict["thumbnailPath"] = thumbnail_path
        if privacy is not UNSET:
            field_dict["privacy"] = privacy
        if type_ is not UNSET:
            field_dict["type"] = type_
        if owner_account is not UNSET:
            field_dict["ownerAccount"] = owner_account
        if video_channel is not UNSET:
            field_dict["videoChannel"] = video_channel
        if video_channel_position is not UNSET:
            field_dict["videoChannelPosition"] = video_channel_position

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.account_summary import AccountSummary
        from peertube.models.video_channel_summary import VideoChannelSummary
        from peertube.models.video_playlist_privacy_constant import (
            VideoPlaylistPrivacyConstant,
        )
        from peertube.models.video_playlist_type_constant import (
            VideoPlaylistTypeConstant,
        )

        d = dict(src_dict)
        id = d.pop("id", UNSET)

        _uuid = d.pop("uuid", UNSET)
        uuid: Unset | UUID
        if isinstance(_uuid, Unset):
            uuid = UNSET
        else:
            uuid = UUID(_uuid)

        short_uuid = d.pop("shortUUID", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Unset | datetime.datetime
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Unset | datetime.datetime
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        description = d.pop("description", UNSET)

        display_name = d.pop("displayName", UNSET)

        is_local = d.pop("isLocal", UNSET)

        video_length = d.pop("videoLength", UNSET)

        thumbnail_path = d.pop("thumbnailPath", UNSET)

        _privacy = d.pop("privacy", UNSET)
        privacy: Unset | VideoPlaylistPrivacyConstant
        if isinstance(_privacy, Unset):
            privacy = UNSET
        else:
            privacy = VideoPlaylistPrivacyConstant.from_dict(_privacy)

        _type_ = d.pop("type", UNSET)
        type_: Unset | VideoPlaylistTypeConstant
        if isinstance(_type_, Unset):
            type_ = UNSET
        else:
            type_ = VideoPlaylistTypeConstant.from_dict(_type_)

        _owner_account = d.pop("ownerAccount", UNSET)
        owner_account: Unset | AccountSummary
        if isinstance(_owner_account, Unset):
            owner_account = UNSET
        else:
            owner_account = AccountSummary.from_dict(_owner_account)

        _video_channel = d.pop("videoChannel", UNSET)
        video_channel: Unset | VideoChannelSummary
        if isinstance(_video_channel, Unset):
            video_channel = UNSET
        else:
            video_channel = VideoChannelSummary.from_dict(_video_channel)

        video_channel_position = d.pop("videoChannelPosition", UNSET)

        video_playlist = cls(
            id=id,
            uuid=uuid,
            short_uuid=short_uuid,
            created_at=created_at,
            updated_at=updated_at,
            description=description,
            display_name=display_name,
            is_local=is_local,
            video_length=video_length,
            thumbnail_path=thumbnail_path,
            privacy=privacy,
            type_=type_,
            owner_account=owner_account,
            video_channel=video_channel,
            video_channel_position=video_channel_position,
        )

        video_playlist.additional_properties = d
        return video_playlist

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.models.mrss_peer_link_type import MRSSPeerLinkType
from peertube.types import UNSET, Unset

T = TypeVar("T", bound="MRSSPeerLink")


@_attrs_define
class MRSSPeerLink:
    """Attributes:
    href (Union[Unset, str]):
    type_ (Union[Unset, MRSSPeerLinkType]):
    """

    href: Unset | str = UNSET
    type_: Unset | MRSSPeerLinkType = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert to dictionary."""

        href = self.href

        type_: Unset | str = UNSET
        if not isinstance(self.type_, Unset):
            type_ = self.type_.value

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if href is not UNSET:
            field_dict["href"] = href
        if type_ is not UNSET:
            field_dict["type"] = type_

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create from dictionary."""

        d = dict(src_dict)
        href = d.pop("href", UNSET)

        _type_ = d.pop("type", UNSET)
        type_: Unset | MRSSPeerLinkType
        if isinstance(_type_, Unset):
            type_ = UNSET
        else:
            type_ = MRSSPeerLinkType(_type_)

        mrss_peer_link = cls(href=href, type_=type_)

        mrss_peer_link.additional_properties = d
        return mrss_peer_link

    @property
    def additional_keys(self) -> list[str]:
        """Get additional keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.server_config_custom_defaults_p2p import (
        ServerConfigCustomDefaultsP2P,
    )
    from peertube.models.server_config_custom_defaults_player import (
        ServerConfigCustomDefaultsPlayer,
    )
    from peertube.models.server_config_custom_defaults_publish import (
        ServerConfigCustomDefaultsPublish,
    )


T = TypeVar("T", bound="ServerConfigCustomDefaults")


@_attrs_define
class ServerConfigCustomDefaults:
    """Attributes:
    publish (Union[Unset, ServerConfigCustomDefaultsPublish]):
    p2p (Union[Unset, ServerConfigCustomDefaultsP2P]):
    player (Union[Unset, ServerConfigCustomDefaultsPlayer]):
    """

    publish: Union[Unset, "ServerConfigCustomDefaultsPublish"] = UNSET
    p2p: Union[Unset, "ServerConfigCustomDefaultsP2P"] = UNSET
    player: Union[Unset, "ServerConfigCustomDefaultsPlayer"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        publish: Unset | dict[str, Any] = UNSET
        if not isinstance(self.publish, Unset):
            publish = self.publish.to_dict()

        p2p: Unset | dict[str, Any] = UNSET
        if not isinstance(self.p2p, Unset):
            p2p = self.p2p.to_dict()

        player: Unset | dict[str, Any] = UNSET
        if not isinstance(self.player, Unset):
            player = self.player.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if publish is not UNSET:
            field_dict["publish"] = publish
        if p2p is not UNSET:
            field_dict["p2p"] = p2p
        if player is not UNSET:
            field_dict["player"] = player

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.server_config_custom_defaults_p2p import (
            ServerConfigCustomDefaultsP2P,
        )
        from peertube.models.server_config_custom_defaults_player import (
            ServerConfigCustomDefaultsPlayer,
        )
        from peertube.models.server_config_custom_defaults_publish import (
            ServerConfigCustomDefaultsPublish,
        )

        d = dict(src_dict)
        _publish = d.pop("publish", UNSET)
        publish: Unset | ServerConfigCustomDefaultsPublish
        if isinstance(_publish, Unset):
            publish = UNSET
        else:
            publish = ServerConfigCustomDefaultsPublish.from_dict(_publish)

        _p2p = d.pop("p2p", UNSET)
        p2p: Unset | ServerConfigCustomDefaultsP2P
        if isinstance(_p2p, Unset):
            p2p = UNSET
        else:
            p2p = ServerConfigCustomDefaultsP2P.from_dict(_p2p)

        _player = d.pop("player", UNSET)
        player: Unset | ServerConfigCustomDefaultsPlayer
        if isinstance(_player, Unset):
            player = UNSET
        else:
            player = ServerConfigCustomDefaultsPlayer.from_dict(_player)

        server_config_custom_defaults = cls(publish=publish, p2p=p2p, player=player)

        server_config_custom_defaults.additional_properties = d
        return server_config_custom_defaults

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""Tests for get_api_videos_id_stats_user_agent function."""

from peertube.api.video_stats.get_api_videos_id_stats_user_agent import sync


def test_get_api_videos_id_stats_user_agent_success(httpx_mock, auth_client):
    """Test successful retrieval of video stats by user agent."""
    # Sample response data
    sample_data = {
        "clients": [
            {"name": "Chrome", "viewers": 150.5},
            {"name": "Firefox", "viewers": 75.2},
        ],
        "devices": [
            {"name": "desktop", "viewers": 200.0},
            {"name": "mobile", "viewers": 25.7},
        ],
        "operatingSystem": [
            {"name": "Windows", "viewers": 120.3},
            {"name": "macOS", "viewers": 80.2},
        ],
    }

    # Mock HTTP response
    httpx_mock.add_response(
        method="GET",
        url="https://test.peertube.example/api/v1/videos/123/stats/user-agent",
        status_code=200,
        json=sample_data,
    )

    # Test the function
    result = sync(id=123, client=auth_client)

    assert result is not None
    assert result.clients is not None
    assert len(result.clients) == 2  # type: ignore[arg-type]
    assert result.clients[0].name == "Chrome"  # type: ignore[attr-defined]
    assert result.clients[0].viewers == 150.5  # type: ignore[attr-defined]
    assert result.devices is not None
    assert len(result.devices) == 2  # type: ignore[arg-type]
    assert result.devices[0].name.value == "desktop"  # type: ignore[attr-defined]
    assert result.operating_system is not None
    assert len(result.operating_system) == 2  # type: ignore[arg-type]
    assert result.operating_system[1].name == "macOS"  # type: ignore[attr-defined]



from enum import Enum


class OAuthTokenRefreshTokenGrantType(str, Enum):
    """OAuthTokenRefreshTokenGrantType enumeration."""

    PASSWORD = "password"
    REFRESH_TOKEN = "refresh_token"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.post_api_v1_runners_jobs_request_response_200_available_jobs_item import (
        PostApiV1RunnersJobsRequestResponse200AvailableJobsItem,
    )


T = TypeVar("T", bound="PostApiV1RunnersJobsRequestResponse200")


@_attrs_define
class PostApiV1RunnersJobsRequestResponse200:
    """Attributes:
    available_jobs (Union[Unset, list['PostApiV1RunnersJobsRequestResponse200AvailableJobsItem']]):
    """

    available_jobs: (
        Unset | list["PostApiV1RunnersJobsRequestResponse200AvailableJobsItem"]
    ) = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        available_jobs: Unset | list[dict[str, Any]] = UNSET
        if not isinstance(self.available_jobs, Unset):
            available_jobs = []
            for available_jobs_item_data in self.available_jobs:
                available_jobs_item = available_jobs_item_data.to_dict()
                available_jobs.append(available_jobs_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if available_jobs is not UNSET:
            field_dict["availableJobs"] = available_jobs

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.post_api_v1_runners_jobs_request_response_200_available_jobs_item import (
            PostApiV1RunnersJobsRequestResponse200AvailableJobsItem,
        )

        d = dict(src_dict)
        available_jobs = []
        _available_jobs = d.pop("availableJobs", UNSET)
        for available_jobs_item_data in _available_jobs or []:
            available_jobs_item = (
                PostApiV1RunnersJobsRequestResponse200AvailableJobsItem.from_dict(
                    available_jobs_item_data
                )
            )

            available_jobs.append(available_jobs_item)

        post_api_v1_runners_jobs_request_response_200 = cls(
            available_jobs=available_jobs
        )

        post_api_v1_runners_jobs_request_response_200.additional_properties = d
        return post_api_v1_runners_jobs_request_response_200

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""Get video captions content as text."""

from __future__ import annotations

from typing import Any
from urllib.parse import urljoin
from uuid import UUID

from pydantic import BaseModel, ConfigDict, validate_call

from peertube.api.video_captions.get_video_captions import (
    sync as get_video_captions_sync,
)
from peertube.client import AuthenticatedClient, Client
from peertube.types import UNSET


class CaptionNormalized(BaseModel):
    """Normalized caption data."""

    lang: str | None = None
    url: str

    @classmethod
    def from_raw(cls, cap: Any, base_url: str) -> CaptionNormalized | None:
        """Convert raw caption to normalized form."""
        # Extract language safely, coalescing UNSET to None
        lang_obj = getattr(cap, "language", UNSET)
        lang = None if lang_obj is UNSET else getattr(lang_obj, "id", None)
        if lang is UNSET:
            lang = None

        # Prefer explicit fileUrl, fallback to caption_path
        file_url = getattr(cap, "additional_properties", {}).get("fileUrl")
        if not file_url:
            caption_path = getattr(cap, "caption_path", UNSET)
            if caption_path is UNSET or caption_path is None:
                return None
            # Robustly join base URL and possibly-relative path
            file_url = urljoin(str(base_url).rstrip("/") + "/", str(caption_path))

        return cls(lang=lang, url=file_url)


@validate_call(config=ConfigDict(arbitrary_types_allowed=True))
def get_video_captions_content(
    client: AuthenticatedClient | Client,
    id: UUID | int | str,
    language_filter: str | None = "en",
    *,
    x_peertube_video_password: str | None = None,
) -> str:
    """Get the content of video captions as a string.

    This function wraps get_video_captions to retrieve caption metadata,
    then downloads the VTT file content for the specified language.

    Args:
        client: PeerTube client instance
        id: Video identifier
        language_filter: Language code to filter captions (default: "en")
        x_peertube_video_password: Video-related parameter

    Returns:
        The VTT file content as a string

    Raises:
        ValueError: If no captions are available or specified language not found
        httpx.HTTPError: For network-related issues when downloading captions
        UnicodeDecodeError: If VTT content cannot be decoded as UTF-8
    """
    captions_response = get_video_captions_sync(
        client=client,
        id=id,
        x_peertube_video_password=UNSET
        if x_peertube_video_password is None
        else x_peertube_video_password,
    )

    data = getattr(captions_response, "data", None) or []
    normalized = [
        c for c in (CaptionNormalized.from_raw(c, client.base_url) for c in data) if c
    ]
    if not normalized:
        msg = "No captions available for this video."
        raise ValueError(msg)

    if language_filter:
        selected = next((c for c in normalized if c.lang == language_filter), None)
        if not selected:
            available = sorted({c.lang for c in normalized if c.lang})
            msg = f"Caption language '{language_filter}' not found. Available: {available}"
            raise ValueError(msg)
    else:
        selected = normalized[0]

    r = client.get_httpx_client().get(selected.url)
    r.raise_for_status()
    try:
        return r.content.decode("utf-8")
    except UnicodeDecodeError as exc:
        raise UnicodeDecodeError(
            exc.encoding,
            exc.object,
            exc.start,
            exc.end,
            "Failed to decode caption content as UTF-8",
        ) from exc



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.actor_image import ActorImage
    from peertube.models.server_config_instance_customizations import (
        ServerConfigInstanceCustomizations,
    )
    from peertube.models.server_config_instance_social import ServerConfigInstanceSocial
    from peertube.models.server_config_instance_support import (
        ServerConfigInstanceSupport,
    )


T = TypeVar("T", bound="ServerConfigInstance")


@_attrs_define
class ServerConfigInstance:
    """Attributes:
    name (Union[Unset, str]):
    short_description (Union[Unset, str]):
    default_client_route (Union[Unset, str]):
    is_nsfw (Union[Unset, bool]):
    default_nsfw_policy (Union[Unset, str]):
    server_country (Union[Unset, str]):
    default_language (Union[Unset, str]):
    support (Union[Unset, ServerConfigInstanceSupport]):
    social (Union[Unset, ServerConfigInstanceSocial]):
    customizations (Union[Unset, ServerConfigInstanceCustomizations]):
    avatars (Union[Unset, list['ActorImage']]):
    banners (Union[Unset, list['ActorImage']]):
    """

    name: Unset | str = UNSET
    short_description: Unset | str = UNSET
    default_client_route: Unset | str = UNSET
    is_nsfw: Unset | bool = UNSET
    default_nsfw_policy: Unset | str = UNSET
    server_country: Unset | str = UNSET
    default_language: Unset | str = UNSET
    support: Union[Unset, "ServerConfigInstanceSupport"] = UNSET
    social: Union[Unset, "ServerConfigInstanceSocial"] = UNSET
    customizations: Union[Unset, "ServerConfigInstanceCustomizations"] = UNSET
    avatars: Unset | list["ActorImage"] = UNSET
    banners: Unset | list["ActorImage"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        name = self.name

        short_description = self.short_description

        default_client_route = self.default_client_route

        is_nsfw = self.is_nsfw

        default_nsfw_policy = self.default_nsfw_policy

        server_country = self.server_country

        default_language = self.default_language

        support: Unset | dict[str, Any] = UNSET
        if not isinstance(self.support, Unset):
            support = self.support.to_dict()

        social: Unset | dict[str, Any] = UNSET
        if not isinstance(self.social, Unset):
            social = self.social.to_dict()

        customizations: Unset | dict[str, Any] = UNSET
        if not isinstance(self.customizations, Unset):
            customizations = self.customizations.to_dict()

        avatars: Unset | list[dict[str, Any]] = UNSET
        if not isinstance(self.avatars, Unset):
            avatars = []
            for avatars_item_data in self.avatars:
                avatars_item = avatars_item_data.to_dict()
                avatars.append(avatars_item)

        banners: Unset | list[dict[str, Any]] = UNSET
        if not isinstance(self.banners, Unset):
            banners = []
            for banners_item_data in self.banners:
                banners_item = banners_item_data.to_dict()
                banners.append(banners_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if name is not UNSET:
            field_dict["name"] = name
        if short_description is not UNSET:
            field_dict["shortDescription"] = short_description
        if default_client_route is not UNSET:
            field_dict["defaultClientRoute"] = default_client_route
        if is_nsfw is not UNSET:
            field_dict["isNSFW"] = is_nsfw
        if default_nsfw_policy is not UNSET:
            field_dict["defaultNSFWPolicy"] = default_nsfw_policy
        if server_country is not UNSET:
            field_dict["serverCountry"] = server_country
        if default_language is not UNSET:
            field_dict["defaultLanguage"] = default_language
        if support is not UNSET:
            field_dict["support"] = support
        if social is not UNSET:
            field_dict["social"] = social
        if customizations is not UNSET:
            field_dict["customizations"] = customizations
        if avatars is not UNSET:
            field_dict["avatars"] = avatars
        if banners is not UNSET:
            field_dict["banners"] = banners

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.actor_image import ActorImage
        from peertube.models.server_config_instance_customizations import (
            ServerConfigInstanceCustomizations,
        )
        from peertube.models.server_config_instance_social import (
            ServerConfigInstanceSocial,
        )
        from peertube.models.server_config_instance_support import (
            ServerConfigInstanceSupport,
        )

        d = dict(src_dict)
        name = d.pop("name", UNSET)

        short_description = d.pop("shortDescription", UNSET)

        default_client_route = d.pop("defaultClientRoute", UNSET)

        is_nsfw = d.pop("isNSFW", UNSET)

        default_nsfw_policy = d.pop("defaultNSFWPolicy", UNSET)

        server_country = d.pop("serverCountry", UNSET)

        default_language = d.pop("defaultLanguage", UNSET)

        _support = d.pop("support", UNSET)
        support: Unset | ServerConfigInstanceSupport
        if isinstance(_support, Unset):
            support = UNSET
        else:
            support = ServerConfigInstanceSupport.from_dict(_support)

        _social = d.pop("social", UNSET)
        social: Unset | ServerConfigInstanceSocial
        if isinstance(_social, Unset):
            social = UNSET
        else:
            social = ServerConfigInstanceSocial.from_dict(_social)

        _customizations = d.pop("customizations", UNSET)
        customizations: Unset | ServerConfigInstanceCustomizations
        if isinstance(_customizations, Unset):
            customizations = UNSET
        else:
            customizations = ServerConfigInstanceCustomizations.from_dict(
                _customizations
            )

        avatars = []
        _avatars = d.pop("avatars", UNSET)
        for avatars_item_data in _avatars or []:
            avatars_item = ActorImage.from_dict(avatars_item_data)

            avatars.append(avatars_item)

        banners = []
        _banners = d.pop("banners", UNSET)
        for banners_item_data in _banners or []:
            banners_item = ActorImage.from_dict(banners_item_data)

            banners.append(banners_item)

        server_config_instance = cls(
            name=name,
            short_description=short_description,
            default_client_route=default_client_route,
            is_nsfw=is_nsfw,
            default_nsfw_policy=default_nsfw_policy,
            server_country=server_country,
            default_language=default_language,
            support=support,
            social=social,
            customizations=customizations,
            avatars=avatars,
            banners=banners,
        )

        server_config_instance.additional_properties = d
        return server_config_instance

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import io

import httpx
import pytest

from peertube.client import AuthenticatedClient, Client
from peertube.types import File, Unset


@pytest.fixture
def base_url():
    """Base URL for test instances"""
    return "https://test.peertube.example"


@pytest.fixture
def test_token():
    """Test authentication token"""
    return "test_auth_token_123"


@pytest.fixture
def client(base_url):
    """Basic Client instance for testing"""
    return Client(base_url=base_url)


@pytest.fixture
def auth_client(base_url, test_token):
    """AuthenticatedClient instance for testing"""
    return AuthenticatedClient(base_url=base_url, token=test_token)


@pytest.fixture
def sample_headers():
    """Sample headers for testing"""
    return {"User-Agent": "test-agent", "Accept": "application/json"}


@pytest.fixture
def sample_cookies():
    """Sample cookies for testing"""
    return {"session": "abc123", "prefs": "dark_mode"}


@pytest.fixture
def timeout_config():
    """Sample timeout configuration for testing"""
    return httpx.Timeout(10.0)


@pytest.fixture
def mock_httpx_client(mocker):
    """Mock httpx.Client for testing"""
    return mocker.Mock(spec=httpx.Client)


@pytest.fixture
def mock_async_httpx_client(mocker):
    """Mock httpx.AsyncClient for testing"""
    return mocker.Mock(spec=httpx.AsyncClient)


@pytest.fixture
def sample_file():
    """Sample File object for testing"""
    return File(payload=io.BytesIO(b"test content"), file_name="test.txt")


@pytest.fixture
def unset_instance():
    """Unset instance for testing"""
    return Unset()


@pytest.fixture
def unexpected_status_args():
    """Arguments for UnexpectedStatus exception testing"""
    return {"status_code": 400, "content": b"Bad Request"}



from typing import Any

from peertube.api.base.endpoint_base import BaseEndpoint
from peertube.client import AuthenticatedClient, Client
from peertube.types import Response


class GetAccountEndpoint(BaseEndpoint):
    """Endpoint for getting an account."""

    @property
    def path(self) -> str:
        """API path for the endpoint."""
        return "/api/v1/accounts/{name}"

    @property
    def method(self) -> str:
        """HTTP method for the endpoint."""
        return "get"

    @property
    def response_model(self) -> type[Any] | None:
        """Response model class, if any."""
        return None  # Returns Any

    def _get_kwargs(self, *args: Any, **kwargs: Any) -> dict[str, Any]:  # noqa: ARG002
        name = args[0]  # First positional argument
        return {
            "method": self.method,
            "url": self.path.format(name=name),
        }


# Backward compatibility functions
def sync_detailed(name: str, *, client: AuthenticatedClient | Client) -> Response[Any]:
    """Get an account

    Args:
        name (str):  Example: chocobozzz | chocobozzz@example.org.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """
    endpoint = GetAccountEndpoint()
    return endpoint.sync_detailed(name, client=client)


def sync(name: str, *, client: AuthenticatedClient | Client) -> Any | None:
    """Get an account

    Args:
        name (str): Example: chocobozzz | chocobozzz@example.org.
        client: The HTTP client instance.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Any
    """
    endpoint = GetAccountEndpoint()
    return endpoint.sync(name, client=client)


async def asyncio_detailed(
    name: str, *, client: AuthenticatedClient | Client
) -> Response[Any]:
    """Get an account

    Args:
        name (str):  Example: chocobozzz | chocobozzz@example.org.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """
    endpoint = GetAccountEndpoint()
    return await endpoint.asyncio_detailed(name, client=client)


async def asyncio(name: str, *, client: AuthenticatedClient | Client) -> Any | None:
    """Get an account

    Args:
        name (str): Example: chocobozzz | chocobozzz@example.org.
        client: The HTTP client instance.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Any
    """
    endpoint = GetAccountEndpoint()
    return await endpoint.asyncio(name, client=client)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.add_user_response_user import AddUserResponseUser


T = TypeVar("T", bound="AddUserResponse")


@_attrs_define
class AddUserResponse:
    """Attributes:
    user (Union[Unset, AddUserResponseUser]):
    """

    user: Union[Unset, "AddUserResponseUser"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        user: Unset | dict[str, Any] = UNSET
        if not isinstance(self.user, Unset):
            user = self.user.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if user is not UNSET:
            field_dict["user"] = user

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.add_user_response_user import AddUserResponseUser

        d = dict(src_dict)
        _user = d.pop("user", UNSET)
        user: Unset | AddUserResponseUser
        if isinstance(_user, Unset):
            user = UNSET
        else:
            user = AddUserResponseUser.from_dict(_user)

        add_user_response = cls(user=user)

        add_user_response.additional_properties = d
        return add_user_response

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class DeleteApiV1ConfigInstanceLogoLogoTypeLogoType(str, Enum):
    """DeleteApiV1ConfigInstanceLogoLogoTypeLogoType enumeration."""

    FAVICON = "favicon"
    HEADER_SQUARE = "header-square"
    HEADER_WIDE = "header-wide"
    OPENGRAPH = "opengraph"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.models.video_comments_policy_set import VideoCommentsPolicySet
from peertube.models.video_privacy_set import VideoPrivacySet
from peertube.types import UNSET, Unset

T = TypeVar("T", bound="ServerConfigCustomDefaultsPublish")


@_attrs_define
class ServerConfigCustomDefaultsPublish:
    """Attributes:
    download_enabled (Union[Unset, bool]):
    comments_policy (Union[Unset, VideoCommentsPolicySet]): Comments policy of the video (Enabled=`1`, Disabled=`2`, Requires Approval=`3`)
    privacy (Union[Unset, VideoPrivacySet]): privacy id of the video (see
        [/videos/privacies](#operation/getVideoPrivacyPolicies))
    licence (Union[Unset, int]): licence id of the video (see [/videos/licences](#operation/getLicences)) Example:
        2.
    """

    download_enabled: Unset | bool = UNSET
    comments_policy: Unset | VideoCommentsPolicySet = UNSET
    privacy: Unset | VideoPrivacySet = UNSET
    licence: Unset | int = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        download_enabled = self.download_enabled

        comments_policy: Unset | int = UNSET
        if not isinstance(self.comments_policy, Unset):
            comments_policy = self.comments_policy.value

        privacy: Unset | int = UNSET
        if not isinstance(self.privacy, Unset):
            privacy = self.privacy.value

        licence = self.licence

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if download_enabled is not UNSET:
            field_dict["downloadEnabled"] = download_enabled
        if comments_policy is not UNSET:
            field_dict["commentsPolicy"] = comments_policy
        if privacy is not UNSET:
            field_dict["privacy"] = privacy
        if licence is not UNSET:
            field_dict["licence"] = licence

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        d = dict(src_dict)
        download_enabled = d.pop("downloadEnabled", UNSET)

        _comments_policy = d.pop("commentsPolicy", UNSET)
        comments_policy: Unset | VideoCommentsPolicySet
        if isinstance(_comments_policy, Unset):
            comments_policy = UNSET
        else:
            comments_policy = VideoCommentsPolicySet(_comments_policy)

        _privacy = d.pop("privacy", UNSET)
        privacy: Unset | VideoPrivacySet
        if isinstance(_privacy, Unset):
            privacy = UNSET
        else:
            privacy = VideoPrivacySet(_privacy)

        licence = d.pop("licence", UNSET)

        server_config_custom_defaults_publish = cls(
            download_enabled=download_enabled,
            comments_policy=comments_policy,
            privacy=privacy,
            licence=licence,
        )

        server_config_custom_defaults_publish.additional_properties = d
        return server_config_custom_defaults_publish

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""Tests for reorder_video_playlists_of_channel function."""

from peertube.api.video_playlists.reorder_video_playlists_of_channel import sync
from peertube.models.reorder_video_playlists_of_channel_body import (
    ReorderVideoPlaylistsOfChannelBody,
)


def test_reorder_video_playlists_of_channel_success(httpx_mock, auth_client):
    """Test successful reordering of channel playlists."""
    # Create request body
    body = ReorderVideoPlaylistsOfChannelBody(
        start_position=1,
        insert_after_position=2,
    )

    # Mock HTTP response
    httpx_mock.add_response(
        method="POST",
        url="https://test.peertube.example/api/v1/video-channels/test-channel/video-playlists/reorder",
        status_code=204,
    )

    # Test the function
    result = sync(channel_handle="test-channel", client=auth_client, body=body)

    assert result is None



from http import HTTPStatus
from typing import TypeVar

import httpx

from peertube import errors
from peertube.client import AuthenticatedClient, Client
from peertube.types import Response

T = TypeVar("T")


def handle_response(
    *,
    client: AuthenticatedClient | Client,
    response: httpx.Response,
    response_model: type[T] | None = None,
) -> T | None:
    """Generic response handler for API endpoints.

    Args:
        client: The HTTP client instance.
        response: The HTTP response.
        response_model: The model class to parse the response into, if any.

    Returns:
        Parsed response model or None.

    Raises:
        errors.UnexpectedStatus: If the status code is unexpected and client.raise_on_unexpected_status is True.
    """
    if response.status_code == 200:
        if response_model is not None:
            return response_model.from_dict(response.json())  # type: ignore[reportAttributeAccessIssue]
        else:
            return response.json()
    if response.status_code == 404:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def build_response(
    *,
    client: AuthenticatedClient | Client,
    response: httpx.Response,
    response_model: type[T] | None = None,
) -> Response[T]:
    """Build a Response object with parsed content.

    Args:
        client: The HTTP client instance.
        response: The HTTP response.
        response_model: The model class to parse the response into, if any.

    Returns:
        Response object with parsed content.
    """
    parsed = handle_response(
        client=client,
        response=response,
        response_model=response_model,
    )
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=parsed,
    )



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.models.server_config_custom_transcoding_profile import (
    ServerConfigCustomTranscodingProfile,
)
from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.server_config_custom_transcoding_hls import (
        ServerConfigCustomTranscodingHls,
    )
    from peertube.models.server_config_custom_transcoding_original_file import (
        ServerConfigCustomTranscodingOriginalFile,
    )
    from peertube.models.server_config_custom_transcoding_resolutions import (
        ServerConfigCustomTranscodingResolutions,
    )
    from peertube.models.server_config_custom_transcoding_web_videos import (
        ServerConfigCustomTranscodingWebVideos,
    )


T = TypeVar("T", bound="ServerConfigCustomTranscoding")


@_attrs_define
class ServerConfigCustomTranscoding:
    """Settings pertaining to transcoding jobs

    Attributes:
        enabled (Union[Unset, bool]):
        original_file (Union[Unset, ServerConfigCustomTranscodingOriginalFile]):
        allow_additional_extensions (Union[Unset, bool]): Allow your users to upload .mkv, .mov, .avi, .wmv, .flv, .f4v, .3g2, .3gp, .mts, m2ts, .mxf, .nut videos
        allow_audio_files (Union[Unset, bool]): If a user uploads an audio file, PeerTube will create a video by merging
            the preview file and the audio file
        threads (Union[Unset, int]): Amount of threads used by ffmpeg for 1 transcoding job
        concurrency (Union[Unset, float]): Amount of transcoding jobs to execute in parallel
        profile (Union[Unset, ServerConfigCustomTranscodingProfile]): New profiles can be added by plugins ; available
            in core PeerTube: 'default'.
        resolutions (Union[Unset, ServerConfigCustomTranscodingResolutions]): Resolutions to transcode _new videos_ to
        web_videos (Union[Unset, ServerConfigCustomTranscodingWebVideos]): Web Video specific settings
        hls (Union[Unset, ServerConfigCustomTranscodingHls]): HLS specific settings
    """

    enabled: Unset | bool = UNSET
    original_file: Union[Unset, "ServerConfigCustomTranscodingOriginalFile"] = UNSET
    allow_additional_extensions: Unset | bool = UNSET
    allow_audio_files: Unset | bool = UNSET
    threads: Unset | int = UNSET
    concurrency: Unset | float = UNSET
    profile: Unset | ServerConfigCustomTranscodingProfile = UNSET
    resolutions: Union[Unset, "ServerConfigCustomTranscodingResolutions"] = UNSET
    web_videos: Union[Unset, "ServerConfigCustomTranscodingWebVideos"] = UNSET
    hls: Union[Unset, "ServerConfigCustomTranscodingHls"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        enabled = self.enabled

        original_file: Unset | dict[str, Any] = UNSET
        if not isinstance(self.original_file, Unset):
            original_file = self.original_file.to_dict()

        allow_additional_extensions = self.allow_additional_extensions

        allow_audio_files = self.allow_audio_files

        threads = self.threads

        concurrency = self.concurrency

        profile: Unset | str = UNSET
        if not isinstance(self.profile, Unset):
            profile = self.profile.value

        resolutions: Unset | dict[str, Any] = UNSET
        if not isinstance(self.resolutions, Unset):
            resolutions = self.resolutions.to_dict()

        web_videos: Unset | dict[str, Any] = UNSET
        if not isinstance(self.web_videos, Unset):
            web_videos = self.web_videos.to_dict()

        hls: Unset | dict[str, Any] = UNSET
        if not isinstance(self.hls, Unset):
            hls = self.hls.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if original_file is not UNSET:
            field_dict["originalFile"] = original_file
        if allow_additional_extensions is not UNSET:
            field_dict["allowAdditionalExtensions"] = allow_additional_extensions
        if allow_audio_files is not UNSET:
            field_dict["allowAudioFiles"] = allow_audio_files
        if threads is not UNSET:
            field_dict["threads"] = threads
        if concurrency is not UNSET:
            field_dict["concurrency"] = concurrency
        if profile is not UNSET:
            field_dict["profile"] = profile
        if resolutions is not UNSET:
            field_dict["resolutions"] = resolutions
        if web_videos is not UNSET:
            field_dict["web_videos"] = web_videos
        if hls is not UNSET:
            field_dict["hls"] = hls

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.server_config_custom_transcoding_hls import (
            ServerConfigCustomTranscodingHls,
        )
        from peertube.models.server_config_custom_transcoding_original_file import (
            ServerConfigCustomTranscodingOriginalFile,
        )
        from peertube.models.server_config_custom_transcoding_resolutions import (
            ServerConfigCustomTranscodingResolutions,
        )
        from peertube.models.server_config_custom_transcoding_web_videos import (
            ServerConfigCustomTranscodingWebVideos,
        )

        d = dict(src_dict)
        enabled = d.pop("enabled", UNSET)

        _original_file = d.pop("originalFile", UNSET)
        original_file: Unset | ServerConfigCustomTranscodingOriginalFile
        if isinstance(_original_file, Unset):
            original_file = UNSET
        else:
            original_file = ServerConfigCustomTranscodingOriginalFile.from_dict(
                _original_file
            )

        allow_additional_extensions = d.pop("allowAdditionalExtensions", UNSET)

        allow_audio_files = d.pop("allowAudioFiles", UNSET)

        threads = d.pop("threads", UNSET)

        concurrency = d.pop("concurrency", UNSET)

        _profile = d.pop("profile", UNSET)
        profile: Unset | ServerConfigCustomTranscodingProfile
        if isinstance(_profile, Unset):
            profile = UNSET
        else:
            profile = ServerConfigCustomTranscodingProfile(_profile)

        _resolutions = d.pop("resolutions", UNSET)
        resolutions: Unset | ServerConfigCustomTranscodingResolutions
        if isinstance(_resolutions, Unset):
            resolutions = UNSET
        else:
            resolutions = ServerConfigCustomTranscodingResolutions.from_dict(
                _resolutions
            )

        _web_videos = d.pop("web_videos", UNSET)
        web_videos: Unset | ServerConfigCustomTranscodingWebVideos
        if isinstance(_web_videos, Unset):
            web_videos = UNSET
        else:
            web_videos = ServerConfigCustomTranscodingWebVideos.from_dict(_web_videos)

        _hls = d.pop("hls", UNSET)
        hls: Unset | ServerConfigCustomTranscodingHls
        if isinstance(_hls, Unset):
            hls = UNSET
        else:
            hls = ServerConfigCustomTranscodingHls.from_dict(_hls)

        server_config_custom_transcoding = cls(
            enabled=enabled,
            original_file=original_file,
            allow_additional_extensions=allow_additional_extensions,
            allow_audio_files=allow_audio_files,
            threads=threads,
            concurrency=concurrency,
            profile=profile,
            resolutions=resolutions,
            web_videos=web_videos,
            hls=hls,
        )

        server_config_custom_transcoding.additional_properties = d
        return server_config_custom_transcoding

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.block_status_accounts import BlockStatusAccounts
    from peertube.models.block_status_hosts import BlockStatusHosts


T = TypeVar("T", bound="BlockStatus")


@_attrs_define
class BlockStatus:
    """Attributes:
    accounts (Union[Unset, BlockStatusAccounts]):
    hosts (Union[Unset, BlockStatusHosts]):
    """

    accounts: Union[Unset, "BlockStatusAccounts"] = UNSET
    hosts: Union[Unset, "BlockStatusHosts"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        accounts: Unset | dict[str, Any] = UNSET
        if not isinstance(self.accounts, Unset):
            accounts = self.accounts.to_dict()

        hosts: Unset | dict[str, Any] = UNSET
        if not isinstance(self.hosts, Unset):
            hosts = self.hosts.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if accounts is not UNSET:
            field_dict["accounts"] = accounts
        if hosts is not UNSET:
            field_dict["hosts"] = hosts

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.block_status_accounts import BlockStatusAccounts
        from peertube.models.block_status_hosts import BlockStatusHosts

        d = dict(src_dict)
        _accounts = d.pop("accounts", UNSET)
        accounts: Unset | BlockStatusAccounts
        if isinstance(_accounts, Unset):
            accounts = UNSET
        else:
            accounts = BlockStatusAccounts.from_dict(_accounts)

        _hosts = d.pop("hosts", UNSET)
        hosts: Unset | BlockStatusHosts
        if isinstance(_hosts, Unset):
            hosts = UNSET
        else:
            hosts = BlockStatusHosts.from_dict(_hosts)

        block_status = cls(accounts=accounts, hosts=hosts)

        block_status.additional_properties = d
        return block_status

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any

import httpx
from pydantic import ConfigDict, validate_call

from peertube.api.shared_utils import build_response, parse_response
from peertube.client import AuthenticatedClient, Client
from peertube.models.add_playlist_body import AddPlaylistBody
from peertube.types import Response


def _get_kwargs(*, body: AddPlaylistBody) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/api/v1/video-playlists",
    }
    _kwargs["files"] = body.to_multipart()

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Any | None:
    return parse_response(client=client, response=response)


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[Any]:
    return build_response(client=client, response=response)


@validate_call(config=ConfigDict(arbitrary_types_allowed=True))
def sync_detailed(
    *, client: AuthenticatedClient, body: AddPlaylistBody
) -> Response[Any]:
    """Create a video playlist
     If the video playlist is set as public, `videoChannelId` is mandatory.

    Args:
        body (AddPlaylistBody): Request body data.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(body=body)

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


@validate_call(config=ConfigDict(arbitrary_types_allowed=True))
def sync(*, client: AuthenticatedClient, body: AddPlaylistBody) -> Any | None:
    """Create a video playlist


    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Any
    """

    return sync_detailed(client=client, body=body).parsed


@validate_call(config=ConfigDict(arbitrary_types_allowed=True))
async def asyncio_detailed(
    *, client: AuthenticatedClient, body: AddPlaylistBody
) -> Response[Any]:
    """Create a video playlist
     If the video playlist is set as public, `videoChannelId` is mandatory.

    Args:
        body (AddPlaylistBody): Request body data.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(body=body)

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)



from typing import Any

import httpx

from peertube import errors
from peertube.api.shared_utils import build_response
from peertube.client import AuthenticatedClient, Client
from peertube.types import UNSET, Response, Unset


def _get_kwargs(
    *, start: Unset | int = UNSET, count: Unset | int = 15, sort: Unset | str = UNSET
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["start"] = start

    params["count"] = count

    params["sort"] = sort
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/api/v1/server/blocklist/servers",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Any | None:
    if response.status_code == 200:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[Any]:
    return build_response(client=client, response=response)


def sync_detailed(
    *,
    client: AuthenticatedClient,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> Response[Any]:
    """List server blocks


    Args:
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        sort (Union[Unset, str]):  Example: -createdAt.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(start=start, count=count, sort=sort)

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> Any | None:
    """List server blocks


    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Any
    """

    return sync_detailed(client=client, start=start, count=count, sort=sort).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> Response[Any]:
    """List server blocks


    Args:
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        sort (Union[Unset, str]):  Example: -createdAt.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(start=start, count=count, sort=sort)

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)



from enum import IntEnum


class VideoPlaylistPrivacySet(IntEnum):
    """VideoPlaylistPrivacySet enumeration."""

    VALUE_1 = 1
    VALUE_2 = 2
    VALUE_3 = 3

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.actor_image import ActorImage


T = TypeVar("T", bound="Actor")


@_attrs_define
class Actor:
    """Attributes:
    id (Union[Unset, int]):  Example: 42.
    url (Union[Unset, str]):
    name (Union[Unset, str]): immutable name of the user, used to find or mention its actor Example: chocobozzz.
    avatars (Union[Unset, list['ActorImage']]):
    host (Union[Unset, str]): server on which the actor is resident
    host_redundancy_allowed (Union[None, Unset, bool]): whether this actor's host allows redundancy of its videos
    following_count (Union[Unset, int]): number of actors subscribed to by this actor, as seen by this instance
    followers_count (Union[Unset, int]): number of followers of this actor, as seen by this instance
    created_at (Union[Unset, datetime.datetime]):
    updated_at (Union[Unset, datetime.datetime]):
    """

    id: Unset | int = UNSET
    url: Unset | str = UNSET
    name: Unset | str = UNSET
    avatars: Unset | list["ActorImage"] = UNSET
    host: Unset | str = UNSET
    host_redundancy_allowed: None | Unset | bool = UNSET
    following_count: Unset | int = UNSET
    followers_count: Unset | int = UNSET
    created_at: Unset | datetime.datetime = UNSET
    updated_at: Unset | datetime.datetime = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        id = self.id

        url = self.url

        name = self.name

        avatars: Unset | list[dict[str, Any]] = UNSET
        if not isinstance(self.avatars, Unset):
            avatars = []
            for avatars_item_data in self.avatars:
                avatars_item = avatars_item_data.to_dict()
                avatars.append(avatars_item)

        host = self.host

        host_redundancy_allowed: None | Unset | bool
        if isinstance(self.host_redundancy_allowed, Unset):
            host_redundancy_allowed = UNSET
        else:
            host_redundancy_allowed = self.host_redundancy_allowed

        following_count = self.following_count

        followers_count = self.followers_count

        created_at: Unset | str = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Unset | str = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if url is not UNSET:
            field_dict["url"] = url
        if name is not UNSET:
            field_dict["name"] = name
        if avatars is not UNSET:
            field_dict["avatars"] = avatars
        if host is not UNSET:
            field_dict["host"] = host
        if host_redundancy_allowed is not UNSET:
            field_dict["hostRedundancyAllowed"] = host_redundancy_allowed
        if following_count is not UNSET:
            field_dict["followingCount"] = following_count
        if followers_count is not UNSET:
            field_dict["followersCount"] = followers_count
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.actor_image import ActorImage

        d = dict(src_dict)
        id = d.pop("id", UNSET)

        url = d.pop("url", UNSET)

        name = d.pop("name", UNSET)

        avatars = []
        _avatars = d.pop("avatars", UNSET)
        for avatars_item_data in _avatars or []:
            avatars_item = ActorImage.from_dict(avatars_item_data)

            avatars.append(avatars_item)

        host = d.pop("host", UNSET)

        def _parse_host_redundancy_allowed(data: object) -> None | Unset | bool:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast("None | Unset | bool", data)

        host_redundancy_allowed = _parse_host_redundancy_allowed(
            d.pop("hostRedundancyAllowed", UNSET)
        )

        following_count = d.pop("followingCount", UNSET)

        followers_count = d.pop("followersCount", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Unset | datetime.datetime
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Unset | datetime.datetime
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        actor = cls(
            id=id,
            url=url,
            name=name,
            avatars=avatars,
            host=host,
            host_redundancy_allowed=host_redundancy_allowed,
            following_count=following_count,
            followers_count=followers_count,
            created_at=created_at,
            updated_at=updated_at,
        )

        actor.additional_properties = d
        return actor

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import IntEnum


class SearchVideosInclude(IntEnum):
    """SearchVideosInclude enumeration."""

    VALUE_0 = 0
    VALUE_1 = 1
    VALUE_2 = 2
    VALUE_4 = 4
    VALUE_8 = 8
    VALUE_16 = 16
    VALUE_32 = 32

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse
from typing_extensions import Self

from peertube.types import UNSET, Unset

T = TypeVar("T", bound="TokenSession")


@_attrs_define
class TokenSession:
    """Attributes:
    id (Union[Unset, int]):
    current_session (Union[Unset, bool]): Is this session the current one?
    login_device (Union[Unset, str]): Device used to login
    login_ip (Union[Unset, str]): IP address used to login
    login_date (Union[Unset, datetime.datetime]): Date of the login
    last_activity_device (Union[Unset, str]):
    last_activity_ip (Union[Unset, str]):
    last_activity_date (Union[Unset, datetime.datetime]):
    created_at (Union[Unset, datetime.datetime]):
    """

    id: Unset | int = UNSET
    current_session: Unset | bool = UNSET
    login_device: Unset | str = UNSET
    login_ip: Unset | str = UNSET
    login_date: Unset | datetime.datetime = UNSET
    last_activity_device: Unset | str = UNSET
    last_activity_ip: Unset | str = UNSET
    last_activity_date: Unset | datetime.datetime = UNSET
    created_at: Unset | datetime.datetime = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        id = self.id

        current_session = self.current_session

        login_device = self.login_device

        login_ip = self.login_ip

        login_date: Unset | str = UNSET
        if not isinstance(self.login_date, Unset):
            login_date = self.login_date.isoformat()

        last_activity_device = self.last_activity_device

        last_activity_ip = self.last_activity_ip

        last_activity_date: Unset | str = UNSET
        if not isinstance(self.last_activity_date, Unset):
            last_activity_date = self.last_activity_date.isoformat()

        created_at: Unset | str = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if current_session is not UNSET:
            field_dict["currentSession"] = current_session
        if login_device is not UNSET:
            field_dict["loginDevice"] = login_device
        if login_ip is not UNSET:
            field_dict["loginIP"] = login_ip
        if login_date is not UNSET:
            field_dict["loginDate"] = login_date
        if last_activity_device is not UNSET:
            field_dict["lastActivityDevice"] = last_activity_device
        if last_activity_ip is not UNSET:
            field_dict["lastActivityIP"] = last_activity_ip
        if last_activity_date is not UNSET:
            field_dict["lastActivityDate"] = last_activity_date
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        d = dict(src_dict)
        id = d.pop("id", UNSET)

        current_session = d.pop("currentSession", UNSET)

        login_device = d.pop("loginDevice", UNSET)

        login_ip = d.pop("loginIP", UNSET)

        _login_date = d.pop("loginDate", UNSET)
        login_date: Unset | datetime.datetime
        if isinstance(_login_date, Unset):
            login_date = UNSET
        else:
            login_date = isoparse(_login_date)

        last_activity_device = d.pop("lastActivityDevice", UNSET)

        last_activity_ip = d.pop("lastActivityIP", UNSET)

        _last_activity_date = d.pop("lastActivityDate", UNSET)
        last_activity_date: Unset | datetime.datetime
        if isinstance(_last_activity_date, Unset):
            last_activity_date = UNSET
        else:
            last_activity_date = isoparse(_last_activity_date)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Unset | datetime.datetime
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        token_session = cls(
            id=id,
            current_session=current_session,
            login_device=login_device,
            login_ip=login_ip,
            login_date=login_date,
            last_activity_device=last_activity_device,
            last_activity_ip=last_activity_ip,
            last_activity_date=last_activity_date,
            created_at=created_at,
        )

        token_session.additional_properties = d
        return token_session

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class GetApiV1ServerFollowingActorType(str, Enum):
    """GetApiV1ServerFollowingActorType enumeration."""

    APPLICATION = "Application"
    GROUP = "Group"
    ORGANIZATION = "Organization"
    PERSON = "Person"
    SERVICE = "Service"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

T = TypeVar("T", bound="CutOptions")


@_attrs_define
class CutOptions:
    """Attributes:
    start (Union[Unset, int]):
    end (Union[Unset, int]):
    """

    start: Unset | int = UNSET
    end: Unset | int = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        start = self.start

        end = self.end

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if start is not UNSET:
            field_dict["start"] = start
        if end is not UNSET:
            field_dict["end"] = end

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        d = dict(src_dict)
        start = d.pop("start", UNSET)

        end = d.pop("end", UNSET)

        cut_options = cls(start=start, end=end)

        cut_options.additional_properties = d
        return cut_options

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from http import HTTPStatus
from typing import Any, cast

import httpx

from peertube import errors
from peertube.client import AuthenticatedClient, Client
from peertube.models.nsfw_flag import NSFWFlag
from peertube.models.search_videos_include import SearchVideosInclude
from peertube.models.search_videos_nsfw import SearchVideosNsfw
from peertube.models.search_videos_search_target import SearchVideosSearchTarget
from peertube.models.search_videos_skip_count import SearchVideosSkipCount
from peertube.models.search_videos_sort import SearchVideosSort
from peertube.models.video_list_response import VideoListResponse
from peertube.models.video_privacy_set import VideoPrivacySet
from peertube.types import UNSET, Response, Unset


def _get_kwargs(
    *,
    search: str,
    uuids: Unset | Any = UNSET,
    search_target: Unset | SearchVideosSearchTarget = UNSET,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    skip_count: Unset | SearchVideosSkipCount = SearchVideosSkipCount.FALSE,
    sort: Unset | SearchVideosSort = UNSET,
    nsfw: Unset | SearchVideosNsfw = UNSET,
    nsfw_flags_included: Unset | NSFWFlag = UNSET,
    nsfw_flags_excluded: Unset | NSFWFlag = UNSET,
    is_live: Unset | bool = UNSET,
    include_scheduled_live: Unset | bool = UNSET,
    category_one_of: Unset | int | list[int] = UNSET,
    licence_one_of: Unset | int | list[int] = UNSET,
    language_one_of: Unset | list[str] | str = UNSET,
    tags_one_of: Unset | list[str] | str = UNSET,
    tags_all_of: Unset | list[str] | str = UNSET,
    is_local: Unset | bool = UNSET,
    include: Unset | SearchVideosInclude = UNSET,
    has_hls_files: Unset | bool = UNSET,
    has_web_video_files: Unset | bool = UNSET,
    host: Unset | str = UNSET,
    auto_tag_one_of: Unset | list[str] | str = UNSET,
    privacy_one_of: Unset | VideoPrivacySet = UNSET,
    exclude_already_watched: Unset | bool = UNSET,
    start_date: Unset | datetime.datetime = UNSET,
    end_date: Unset | datetime.datetime = UNSET,
    originally_published_start_date: Unset | datetime.datetime = UNSET,
    originally_published_end_date: Unset | datetime.datetime = UNSET,
    duration_min: Unset | int = UNSET,
    duration_max: Unset | int = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["search"] = search

    params["uuids"] = uuids
    json_search_target: Unset | str = UNSET
    if not isinstance(search_target, Unset):
        json_search_target = search_target.value

    params["searchTarget"] = json_search_target

    params["start"] = start

    params["count"] = count
    json_skip_count: Unset | str = UNSET
    if not isinstance(skip_count, Unset):
        json_skip_count = skip_count.value

    params["skipCount"] = json_skip_count
    json_sort: Unset | str = UNSET
    if not isinstance(sort, Unset):
        json_sort = sort.value

    params["sort"] = json_sort
    json_nsfw: Unset | str = UNSET
    if not isinstance(nsfw, Unset):
        json_nsfw = nsfw.value

    params["nsfw"] = json_nsfw
    json_nsfw_flags_included: Unset | int = UNSET
    if not isinstance(nsfw_flags_included, Unset):
        json_nsfw_flags_included = nsfw_flags_included.value

    params["nsfwFlagsIncluded"] = json_nsfw_flags_included
    json_nsfw_flags_excluded: Unset | int = UNSET
    if not isinstance(nsfw_flags_excluded, Unset):
        json_nsfw_flags_excluded = nsfw_flags_excluded.value

    params["nsfwFlagsExcluded"] = json_nsfw_flags_excluded

    params["isLive"] = is_live

    params["includeScheduledLive"] = include_scheduled_live
    json_category_one_of: Unset | int | list[int]
    if isinstance(category_one_of, Unset):
        json_category_one_of = UNSET
    elif isinstance(category_one_of, list):
        json_category_one_of = category_one_of

    else:
        json_category_one_of = category_one_of
    params["categoryOneOf"] = json_category_one_of
    json_licence_one_of: Unset | int | list[int]
    if isinstance(licence_one_of, Unset):
        json_licence_one_of = UNSET
    elif isinstance(licence_one_of, list):
        json_licence_one_of = licence_one_of

    else:
        json_licence_one_of = licence_one_of
    params["licenceOneOf"] = json_licence_one_of
    json_language_one_of: Unset | list[str] | str
    if isinstance(language_one_of, Unset):
        json_language_one_of = UNSET
    elif isinstance(language_one_of, list):
        json_language_one_of = language_one_of

    else:
        json_language_one_of = language_one_of
    params["languageOneOf"] = json_language_one_of
    json_tags_one_of: Unset | list[str] | str
    if isinstance(tags_one_of, Unset):
        json_tags_one_of = UNSET
    elif isinstance(tags_one_of, list):
        json_tags_one_of = tags_one_of

    else:
        json_tags_one_of = tags_one_of
    params["tagsOneOf"] = json_tags_one_of
    json_tags_all_of: Unset | list[str] | str
    if isinstance(tags_all_of, Unset):
        json_tags_all_of = UNSET
    elif isinstance(tags_all_of, list):
        json_tags_all_of = tags_all_of

    else:
        json_tags_all_of = tags_all_of
    params["tagsAllOf"] = json_tags_all_of

    params["isLocal"] = is_local
    json_include: Unset | int = UNSET
    if not isinstance(include, Unset):
        json_include = include.value

    params["include"] = json_include

    params["hasHLSFiles"] = has_hls_files

    params["hasWebVideoFiles"] = has_web_video_files

    params["host"] = host
    json_auto_tag_one_of: Unset | list[str] | str
    if isinstance(auto_tag_one_of, Unset):
        json_auto_tag_one_of = UNSET
    elif isinstance(auto_tag_one_of, list):
        json_auto_tag_one_of = auto_tag_one_of

    else:
        json_auto_tag_one_of = auto_tag_one_of
    params["autoTagOneOf"] = json_auto_tag_one_of
    json_privacy_one_of: Unset | int = UNSET
    if not isinstance(privacy_one_of, Unset):
        json_privacy_one_of = privacy_one_of.value

    params["privacyOneOf"] = json_privacy_one_of

    params["excludeAlreadyWatched"] = exclude_already_watched
    json_start_date: Unset | str = UNSET
    if not isinstance(start_date, Unset):
        json_start_date = start_date.isoformat()
    params["startDate"] = json_start_date
    json_end_date: Unset | str = UNSET
    if not isinstance(end_date, Unset):
        json_end_date = end_date.isoformat()
    params["endDate"] = json_end_date
    json_originally_published_start_date: Unset | str = UNSET
    if not isinstance(originally_published_start_date, Unset):
        json_originally_published_start_date = (
            originally_published_start_date.isoformat()
        )
    params["originallyPublishedStartDate"] = json_originally_published_start_date
    json_originally_published_end_date: Unset | str = UNSET
    if not isinstance(originally_published_end_date, Unset):
        json_originally_published_end_date = originally_published_end_date.isoformat()
    params["originallyPublishedEndDate"] = json_originally_published_end_date

    params["durationMin"] = duration_min

    params["durationMax"] = duration_max
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/api/v1/search/videos",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Any | VideoListResponse | None:
    if response.status_code == 200:
        response_200 = VideoListResponse.from_dict(response.json())

        return response_200
    if response.status_code == 500:
        response_500 = cast("Any", None)
        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[Any | VideoListResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient | Client,
    search: str,
    uuids: Unset | Any = UNSET,
    search_target: Unset | SearchVideosSearchTarget = UNSET,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    skip_count: Unset | SearchVideosSkipCount = SearchVideosSkipCount.FALSE,
    sort: Unset | SearchVideosSort = UNSET,
    nsfw: Unset | SearchVideosNsfw = UNSET,
    nsfw_flags_included: Unset | NSFWFlag = UNSET,
    nsfw_flags_excluded: Unset | NSFWFlag = UNSET,
    is_live: Unset | bool = UNSET,
    include_scheduled_live: Unset | bool = UNSET,
    category_one_of: Unset | int | list[int] = UNSET,
    licence_one_of: Unset | int | list[int] = UNSET,
    language_one_of: Unset | list[str] | str = UNSET,
    tags_one_of: Unset | list[str] | str = UNSET,
    tags_all_of: Unset | list[str] | str = UNSET,
    is_local: Unset | bool = UNSET,
    include: Unset | SearchVideosInclude = UNSET,
    has_hls_files: Unset | bool = UNSET,
    has_web_video_files: Unset | bool = UNSET,
    host: Unset | str = UNSET,
    auto_tag_one_of: Unset | list[str] | str = UNSET,
    privacy_one_of: Unset | VideoPrivacySet = UNSET,
    exclude_already_watched: Unset | bool = UNSET,
    start_date: Unset | datetime.datetime = UNSET,
    end_date: Unset | datetime.datetime = UNSET,
    originally_published_start_date: Unset | datetime.datetime = UNSET,
    originally_published_end_date: Unset | datetime.datetime = UNSET,
    duration_min: Unset | int = UNSET,
    duration_max: Unset | int = UNSET,
) -> Response[Any | VideoListResponse]:
    """Search for videos on the PeerTube instance with detailed response information.
    Performs a video search on the PeerTube instance using various filtering criteria. If the user
    can make a remote URI search and the search string is a URI, the PeerTube instance will fetch
    the remote object and add it to its database for interaction via the REST API.

    Args:
        client: The authenticated or unauthenticated client for making requests.
        search: String to search for. Can be a video title, description, or URI.
        uuids: Filter results to specific video UUIDs.
        search_target: Whether to search locally or use search index. If search index is enabled
            by the administrator, you can override the default search target.
        start: Starting index for pagination (0-based).
        count: Maximum number of videos to return per page. Default: 15.
        skip_count: Whether to skip the total count calculation for performance.
        sort: Sort videos by criteria. Prefix with `-` for descending order. Options include:
            `hot` (Reddit-like algorithm considering views, likes, dislikes, comments, and date), `best` (like hot but includes user history), `trending` (recent views), `views` (total view count), `publishedAt` (publication date).
        nsfw: Filter for NSFW content (show all, only NSFW, or only safe content).
        nsfw_flags_included: Include videos with specific NSFW flags. Can be combined with
            bitwise OR: 0 = NONE, 1=VIOLENT, 2 = EXPLICIT_SEX.
        nsfw_flags_excluded: Exclude videos with specific NSFW flags. Can be combined with
            bitwise OR: 0 = NONE, 1=VIOLENT, 2 = EXPLICIT_SEX.
        is_live: Filter for live videos only.
        include_scheduled_live: Include scheduled live videos in results.
        category_one_of: Filter by video category IDs. Can be a single ID or list of IDs.
        licence_one_of: Filter by video licence IDs. Can be a single ID or list of IDs.
        language_one_of: Filter by language codes. Can be a single language or list of languages.
        tags_one_of: Filter videos that have at least one of the specified tags.
        tags_all_of: Filter videos that have all of the specified tags.
        is_local: Filter for local videos only (hosted on this instance).
        include: Include additional video information in results. Administrators and moderators
            only. Can be combined with bitwise OR: 0 = NONE, 1=NOT_PUBLISHED_STATE, 2=BLACKLISTED, 4=BLOCKED_OWNER, 8=FILES, 16=CAPTIONS, 32 = VIDEO_SOURCE.
        has_hls_files: Filter for videos that have HLS streaming files.
        has_web_video_files: Filter for videos that have web-compatible video files.
        host: Filter by the hostname where videos are hosted.
        auto_tag_one_of: Filter by automatically generated tags.
        privacy_one_of: Filter by video privacy settings (public, unlisted, private, internal).
        exclude_already_watched: Exclude videos that the current user has already watched.
        start_date: Filter for videos published after this date.
        end_date: Filter for videos published before this date.
        originally_published_start_date: Filter for videos originally published after this date.
        originally_published_end_date: Filter for videos originally published before this date.
        duration_min: Filter for videos with at least this duration (in seconds).
        duration_max: Filter for videos with at most this duration (in seconds).

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response object containing the status code, headers, and parsed video list data or error information.
    """

    kwargs = _get_kwargs(
        search=search,
        uuids=uuids,
        search_target=search_target,
        start=start,
        count=count,
        skip_count=skip_count,
        sort=sort,
        nsfw=nsfw,
        nsfw_flags_included=nsfw_flags_included,
        nsfw_flags_excluded=nsfw_flags_excluded,
        is_live=is_live,
        include_scheduled_live=include_scheduled_live,
        category_one_of=category_one_of,
        licence_one_of=licence_one_of,
        language_one_of=language_one_of,
        tags_one_of=tags_one_of,
        tags_all_of=tags_all_of,
        is_local=is_local,
        include=include,
        has_hls_files=has_hls_files,
        has_web_video_files=has_web_video_files,
        host=host,
        auto_tag_one_of=auto_tag_one_of,
        privacy_one_of=privacy_one_of,
        exclude_already_watched=exclude_already_watched,
        start_date=start_date,
        end_date=end_date,
        originally_published_start_date=originally_published_start_date,
        originally_published_end_date=originally_published_end_date,
        duration_min=duration_min,
        duration_max=duration_max,
    )

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient | Client,
    search: str,
    uuids: Unset | Any = UNSET,
    search_target: Unset | SearchVideosSearchTarget = UNSET,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    skip_count: Unset | SearchVideosSkipCount = SearchVideosSkipCount.FALSE,
    sort: Unset | SearchVideosSort = UNSET,
    nsfw: Unset | SearchVideosNsfw = UNSET,
    nsfw_flags_included: Unset | NSFWFlag = UNSET,
    nsfw_flags_excluded: Unset | NSFWFlag = UNSET,
    is_live: Unset | bool = UNSET,
    include_scheduled_live: Unset | bool = UNSET,
    category_one_of: Unset | int | list[int] = UNSET,
    licence_one_of: Unset | int | list[int] = UNSET,
    language_one_of: Unset | list[str] | str = UNSET,
    tags_one_of: Unset | list[str] | str = UNSET,
    tags_all_of: Unset | list[str] | str = UNSET,
    is_local: Unset | bool = UNSET,
    include: Unset | SearchVideosInclude = UNSET,
    has_hls_files: Unset | bool = UNSET,
    has_web_video_files: Unset | bool = UNSET,
    host: Unset | str = UNSET,
    auto_tag_one_of: Unset | list[str] | str = UNSET,
    privacy_one_of: Unset | VideoPrivacySet = UNSET,
    exclude_already_watched: Unset | bool = UNSET,
    start_date: Unset | datetime.datetime = UNSET,
    end_date: Unset | datetime.datetime = UNSET,
    originally_published_start_date: Unset | datetime.datetime = UNSET,
    originally_published_end_date: Unset | datetime.datetime = UNSET,
    duration_min: Unset | int = UNSET,
    duration_max: Unset | int = UNSET,
) -> Any | VideoListResponse | None:
    """Search for videos on the PeerTube instance.
    Performs a video search on the PeerTube instance using various filtering criteria. If the user
    can make a remote URI search and the search string is a URI, the PeerTube instance will fetch
    the remote object and add it to its database for interaction via the REST API.

    Args:
        client: The authenticated or unauthenticated client for making requests.
        search: String to search for. Can be a video title, description, or URI.
        uuids: Filter results to specific video UUIDs.
        search_target: Whether to search locally or use search index. If search index is enabled
            by the administrator, you can override the default search target.
        start: Starting index for pagination (0-based).
        count: Maximum number of videos to return per page. Default: 15.
        skip_count: Whether to skip the total count calculation for performance.
        sort: Sort videos by criteria. Prefix with `-` for descending order. Options include:
            `hot` (Reddit-like algorithm considering views, likes, dislikes, comments, and date), `best` (like hot but includes user history), `trending` (recent views), `views` (total view count), `publishedAt` (publication date).
        nsfw: Filter for NSFW content (show all, only NSFW, or only safe content).
        nsfw_flags_included: Include videos with specific NSFW flags. Can be combined with
            bitwise OR: 0 = NONE, 1=VIOLENT, 2 = EXPLICIT_SEX.
        nsfw_flags_excluded: Exclude videos with specific NSFW flags. Can be combined with
            bitwise OR: 0 = NONE, 1=VIOLENT, 2 = EXPLICIT_SEX.
        is_live: Filter for live videos only.
        include_scheduled_live: Include scheduled live videos in results.
        category_one_of: Filter by video category IDs. Can be a single ID or list of IDs.
        licence_one_of: Filter by video licence IDs. Can be a single ID or list of IDs.
        language_one_of: Filter by language codes. Can be a single language or list of languages.
        tags_one_of: Filter videos that have at least one of the specified tags.
        tags_all_of: Filter videos that have all of the specified tags.
        is_local: Filter for local videos only (hosted on this instance).
        include: Include additional video information in results. Administrators and moderators
            only. Can be combined with bitwise OR: 0 = NONE, 1=NOT_PUBLISHED_STATE, 2=BLACKLISTED, 4=BLOCKED_OWNER, 8=FILES, 16=CAPTIONS, 32 = VIDEO_SOURCE.
        has_hls_files: Filter for videos that have HLS streaming files.
        has_web_video_files: Filter for videos that have web-compatible video files.
        host: Filter by the hostname where videos are hosted.
        auto_tag_one_of: Filter by automatically generated tags.
        privacy_one_of: Filter by video privacy settings (public, unlisted, private, internal).
        exclude_already_watched: Exclude videos that the current user has already watched.
        start_date: Filter for videos published after this date.
        end_date: Filter for videos published before this date.
        originally_published_start_date: Filter for videos originally published after this date.
        originally_published_end_date: Filter for videos originally published before this date.
        duration_min: Filter for videos with at least this duration (in seconds).
        duration_max: Filter for videos with at most this duration (in seconds).

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        The parsed video list response data, or None if the search index is unavailable.
    """

    return sync_detailed(
        client=client,
        search=search,
        uuids=uuids,
        search_target=search_target,
        start=start,
        count=count,
        skip_count=skip_count,
        sort=sort,
        nsfw=nsfw,
        nsfw_flags_included=nsfw_flags_included,
        nsfw_flags_excluded=nsfw_flags_excluded,
        is_live=is_live,
        include_scheduled_live=include_scheduled_live,
        category_one_of=category_one_of,
        licence_one_of=licence_one_of,
        language_one_of=language_one_of,
        tags_one_of=tags_one_of,
        tags_all_of=tags_all_of,
        is_local=is_local,
        include=include,
        has_hls_files=has_hls_files,
        has_web_video_files=has_web_video_files,
        host=host,
        auto_tag_one_of=auto_tag_one_of,
        privacy_one_of=privacy_one_of,
        exclude_already_watched=exclude_already_watched,
        start_date=start_date,
        end_date=end_date,
        originally_published_start_date=originally_published_start_date,
        originally_published_end_date=originally_published_end_date,
        duration_min=duration_min,
        duration_max=duration_max,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient | Client,
    search: str,
    uuids: Unset | Any = UNSET,
    search_target: Unset | SearchVideosSearchTarget = UNSET,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    skip_count: Unset | SearchVideosSkipCount = SearchVideosSkipCount.FALSE,
    sort: Unset | SearchVideosSort = UNSET,
    nsfw: Unset | SearchVideosNsfw = UNSET,
    nsfw_flags_included: Unset | NSFWFlag = UNSET,
    nsfw_flags_excluded: Unset | NSFWFlag = UNSET,
    is_live: Unset | bool = UNSET,
    include_scheduled_live: Unset | bool = UNSET,
    category_one_of: Unset | int | list[int] = UNSET,
    licence_one_of: Unset | int | list[int] = UNSET,
    language_one_of: Unset | list[str] | str = UNSET,
    tags_one_of: Unset | list[str] | str = UNSET,
    tags_all_of: Unset | list[str] | str = UNSET,
    is_local: Unset | bool = UNSET,
    include: Unset | SearchVideosInclude = UNSET,
    has_hls_files: Unset | bool = UNSET,
    has_web_video_files: Unset | bool = UNSET,
    host: Unset | str = UNSET,
    auto_tag_one_of: Unset | list[str] | str = UNSET,
    privacy_one_of: Unset | VideoPrivacySet = UNSET,
    exclude_already_watched: Unset | bool = UNSET,
    start_date: Unset | datetime.datetime = UNSET,
    end_date: Unset | datetime.datetime = UNSET,
    originally_published_start_date: Unset | datetime.datetime = UNSET,
    originally_published_end_date: Unset | datetime.datetime = UNSET,
    duration_min: Unset | int = UNSET,
    duration_max: Unset | int = UNSET,
) -> Response[Any | VideoListResponse]:
    """Search for videos on the PeerTube instance asynchronously with detailed response information.
    Performs an asynchronous video search on the PeerTube instance using various filtering criteria.
    If the user can make a remote URI search and the search string is a URI, the PeerTube instance
    will fetch the remote object and add it to its database for interaction via the REST API.

    Args:
        client: The authenticated or unauthenticated client for making requests.
        search: String to search for. Can be a video title, description, or URI.
        uuids: Filter results to specific video UUIDs.
        search_target: Whether to search locally or use search index. If search index is enabled
            by the administrator, you can override the default search target.
        start: Starting index for pagination (0-based).
        count: Maximum number of videos to return per page. Default: 15.
        skip_count: Whether to skip the total count calculation for performance.
        sort: Sort videos by criteria. Prefix with `-` for descending order. Options include:
            `hot` (Reddit-like algorithm considering views, likes, dislikes, comments, and date), `best` (like hot but includes user history), `trending` (recent views), `views` (total view count), `publishedAt` (publication date).
        nsfw: Filter for NSFW content (show all, only NSFW, or only safe content).
        nsfw_flags_included: Include videos with specific NSFW flags. Can be combined with
            bitwise OR: 0 = NONE, 1=VIOLENT, 2 = EXPLICIT_SEX.
        nsfw_flags_excluded: Exclude videos with specific NSFW flags. Can be combined with
            bitwise OR: 0 = NONE, 1=VIOLENT, 2 = EXPLICIT_SEX.
        is_live: Filter for live videos only.
        include_scheduled_live: Include scheduled live videos in results.
        category_one_of: Filter by video category IDs. Can be a single ID or list of IDs.
        licence_one_of: Filter by video licence IDs. Can be a single ID or list of IDs.
        language_one_of: Filter by language codes. Can be a single language or list of languages.
        tags_one_of: Filter videos that have at least one of the specified tags.
        tags_all_of: Filter videos that have all of the specified tags.
        is_local: Filter for local videos only (hosted on this instance).
        include: Include additional video information in results. Administrators and moderators
            only. Can be combined with bitwise OR: 0 = NONE, 1=NOT_PUBLISHED_STATE, 2=BLACKLISTED, 4=BLOCKED_OWNER, 8=FILES, 16=CAPTIONS, 32 = VIDEO_SOURCE.
        has_hls_files: Filter for videos that have HLS streaming files.
        has_web_video_files: Filter for videos that have web-compatible video files.
        host: Filter by the hostname where videos are hosted.
        auto_tag_one_of: Filter by automatically generated tags.
        privacy_one_of: Filter by video privacy settings (public, unlisted, private, internal).
        exclude_already_watched: Exclude videos that the current user has already watched.
        start_date: Filter for videos published after this date.
        end_date: Filter for videos published before this date.
        originally_published_start_date: Filter for videos originally published after this date.
        originally_published_end_date: Filter for videos originally published before this date.
        duration_min: Filter for videos with at least this duration (in seconds).
        duration_max: Filter for videos with at most this duration (in seconds).

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response object containing the status code, headers, and parsed video list data or error information.
    """

    kwargs = _get_kwargs(
        search=search,
        uuids=uuids,
        search_target=search_target,
        start=start,
        count=count,
        skip_count=skip_count,
        sort=sort,
        nsfw=nsfw,
        nsfw_flags_included=nsfw_flags_included,
        nsfw_flags_excluded=nsfw_flags_excluded,
        is_live=is_live,
        include_scheduled_live=include_scheduled_live,
        category_one_of=category_one_of,
        licence_one_of=licence_one_of,
        language_one_of=language_one_of,
        tags_one_of=tags_one_of,
        tags_all_of=tags_all_of,
        is_local=is_local,
        include=include,
        has_hls_files=has_hls_files,
        has_web_video_files=has_web_video_files,
        host=host,
        auto_tag_one_of=auto_tag_one_of,
        privacy_one_of=privacy_one_of,
        exclude_already_watched=exclude_already_watched,
        start_date=start_date,
        end_date=end_date,
        originally_published_start_date=originally_published_start_date,
        originally_published_end_date=originally_published_end_date,
        duration_min=duration_min,
        duration_max=duration_max,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient | Client,
    search: str,
    uuids: Unset | Any = UNSET,
    search_target: Unset | SearchVideosSearchTarget = UNSET,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    skip_count: Unset | SearchVideosSkipCount = SearchVideosSkipCount.FALSE,
    sort: Unset | SearchVideosSort = UNSET,
    nsfw: Unset | SearchVideosNsfw = UNSET,
    nsfw_flags_included: Unset | NSFWFlag = UNSET,
    nsfw_flags_excluded: Unset | NSFWFlag = UNSET,
    is_live: Unset | bool = UNSET,
    include_scheduled_live: Unset | bool = UNSET,
    category_one_of: Unset | int | list[int] = UNSET,
    licence_one_of: Unset | int | list[int] = UNSET,
    language_one_of: Unset | list[str] | str = UNSET,
    tags_one_of: Unset | list[str] | str = UNSET,
    tags_all_of: Unset | list[str] | str = UNSET,
    is_local: Unset | bool = UNSET,
    include: Unset | SearchVideosInclude = UNSET,
    has_hls_files: Unset | bool = UNSET,
    has_web_video_files: Unset | bool = UNSET,
    host: Unset | str = UNSET,
    auto_tag_one_of: Unset | list[str] | str = UNSET,
    privacy_one_of: Unset | VideoPrivacySet = UNSET,
    exclude_already_watched: Unset | bool = UNSET,
    start_date: Unset | datetime.datetime = UNSET,
    end_date: Unset | datetime.datetime = UNSET,
    originally_published_start_date: Unset | datetime.datetime = UNSET,
    originally_published_end_date: Unset | datetime.datetime = UNSET,
    duration_min: Unset | int = UNSET,
    duration_max: Unset | int = UNSET,
) -> Any | VideoListResponse | None:
    """Search for videos on the PeerTube instance asynchronously.
    Performs an asynchronous video search on the PeerTube instance using various filtering criteria.
    If the user can make a remote URI search and the search string is a URI, the PeerTube instance
    will fetch the remote object and add it to its database for interaction via the REST API.

    Args:
        client: The authenticated or unauthenticated client for making requests.
        search: String to search for. Can be a video title, description, or URI.
        uuids: Filter results to specific video UUIDs.
        search_target: Whether to search locally or use search index. If search index is enabled
            by the administrator, you can override the default search target.
        start: Starting index for pagination (0-based).
        count: Maximum number of videos to return per page. Default: 15.
        skip_count: Whether to skip the total count calculation for performance.
        sort: Sort videos by criteria. Prefix with `-` for descending order. Options include:
            `hot` (Reddit-like algorithm considering views, likes, dislikes, comments, and date), `best` (like hot but includes user history), `trending` (recent views), `views` (total view count), `publishedAt` (publication date).
        nsfw: Filter for NSFW content (show all, only NSFW, or only safe content).
        nsfw_flags_included: Include videos with specific NSFW flags. Can be combined with
            bitwise OR: 0 = NONE, 1=VIOLENT, 2 = EXPLICIT_SEX.
        nsfw_flags_excluded: Exclude videos with specific NSFW flags. Can be combined with
            bitwise OR: 0 = NONE, 1=VIOLENT, 2 = EXPLICIT_SEX.
        is_live: Filter for live videos only.
        include_scheduled_live: Include scheduled live videos in results.
        category_one_of: Filter by video category IDs. Can be a single ID or list of IDs.
        licence_one_of: Filter by video licence IDs. Can be a single ID or list of IDs.
        language_one_of: Filter by language codes. Can be a single language or list of languages.
        tags_one_of: Filter videos that have at least one of the specified tags.
        tags_all_of: Filter videos that have all of the specified tags.
        is_local: Filter for local videos only (hosted on this instance).
        include: Include additional video information in results. Administrators and moderators
            only. Can be combined with bitwise OR: 0 = NONE, 1=NOT_PUBLISHED_STATE, 2=BLACKLISTED, 4=BLOCKED_OWNER, 8=FILES, 16=CAPTIONS, 32 = VIDEO_SOURCE.
        has_hls_files: Filter for videos that have HLS streaming files.
        has_web_video_files: Filter for videos that have web-compatible video files.
        host: Filter by the hostname where videos are hosted.
        auto_tag_one_of: Filter by automatically generated tags.
        privacy_one_of: Filter by video privacy settings (public, unlisted, private, internal).
        exclude_already_watched: Exclude videos that the current user has already watched.
        start_date: Filter for videos published after this date.
        end_date: Filter for videos published before this date.
        originally_published_start_date: Filter for videos originally published after this date.
        originally_published_end_date: Filter for videos originally published before this date.
        duration_min: Filter for videos with at least this duration (in seconds).
        duration_max: Filter for videos with at most this duration (in seconds).

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        The parsed video list response data, or None if the search index is unavailable.
    """

    return (
        await asyncio_detailed(
            client=client,
            search=search,
            uuids=uuids,
            search_target=search_target,
            start=start,
            count=count,
            skip_count=skip_count,
            sort=sort,
            nsfw=nsfw,
            nsfw_flags_included=nsfw_flags_included,
            nsfw_flags_excluded=nsfw_flags_excluded,
            is_live=is_live,
            include_scheduled_live=include_scheduled_live,
            category_one_of=category_one_of,
            licence_one_of=licence_one_of,
            language_one_of=language_one_of,
            tags_one_of=tags_one_of,
            tags_all_of=tags_all_of,
            is_local=is_local,
            include=include,
            has_hls_files=has_hls_files,
            has_web_video_files=has_web_video_files,
            host=host,
            auto_tag_one_of=auto_tag_one_of,
            privacy_one_of=privacy_one_of,
            exclude_already_watched=exclude_already_watched,
            start_date=start_date,
            end_date=end_date,
            originally_published_start_date=originally_published_start_date,
            originally_published_end_date=originally_published_end_date,
            duration_min=duration_min,
            duration_max=duration_max,
        )
    ).parsed



from typing import Any

import httpx

from peertube import errors
from peertube.api.shared_utils import build_response
from peertube.client import AuthenticatedClient, Client
from peertube.types import UNSET, Response, Unset


def _get_kwargs(
    filename: str,
    *,
    video_file_token: Unset | str = UNSET,
    reinject_video_file_token: Unset | bool = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["videoFileToken"] = video_file_token

    params["reinjectVideoFileToken"] = reinject_video_file_token
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/static/streaming-playlists/hls/private/{filename}",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Any | None:
    if response.status_code == 200:
        return None

    if response.status_code == 403:
        return None

    if response.status_code == 404:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[Any]:
    return build_response(client=client, response=response)


def sync_detailed(
    filename: str,
    *,
    client: AuthenticatedClient,
    video_file_token: Unset | str = UNSET,
    reinject_video_file_token: Unset | bool = UNSET,
) -> Response[Any]:
    """Get private HLS video file


    Args:
        filename (str): Parameter for filename.
        video_file_token (Union[Unset, str]): Video-related parameter.
        reinject_video_file_token (Union[Unset, bool]): Video-related parameter.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        filename=filename,
        video_file_token=video_file_token,
        reinject_video_file_token=reinject_video_file_token,
    )

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    filename: str,
    *,
    client: AuthenticatedClient,
    video_file_token: Unset | str = UNSET,
    reinject_video_file_token: Unset | bool = UNSET,
) -> Any | None:
    """Get private HLS video file


    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Any
    """

    return sync_detailed(
        filename=filename,
        client=client,
        video_file_token=video_file_token,
        reinject_video_file_token=reinject_video_file_token,
    ).parsed


async def asyncio_detailed(
    filename: str,
    *,
    client: AuthenticatedClient,
    video_file_token: Unset | str = UNSET,
    reinject_video_file_token: Unset | bool = UNSET,
) -> Response[Any]:
    """Get private HLS video file


    Args:
        filename (str): Parameter for filename.
        video_file_token (Union[Unset, str]): Video-related parameter.
        reinject_video_file_token (Union[Unset, bool]): Video-related parameter.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        filename=filename,
        video_file_token=video_file_token,
        reinject_video_file_token=reinject_video_file_token,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.video_resolution_constant import VideoResolutionConstant


T = TypeVar("T", bound="VideoSource")


@_attrs_define
class VideoSource:
    """Attributes:
    filename (Union[Unset, str]): Deprecated in 6.1, use inputFilename instead
    input_filename (Union[Unset, str]): Uploaded/imported filename
    file_download_url (Union[Unset, str]): **PeerTube >=6.1** If enabled by the admin, the video source file is
        kept on the server and can be downloaded by the owner
    resolution (Union[Unset, VideoResolutionConstant]): resolutions and their labels for the video
    size (Union[Unset, int]): **PeerTube >=6.1** Video file size in bytes
    fps (Union[Unset, float]): **PeerTube >=6.1** Frames per second of the video file
    width (Union[Unset, int]): **PeerTube >=6.1** Video stream width
    height (Union[Unset, int]): **PeerTube >=6.1** Video stream height
    created_at (Union[Unset, datetime.datetime]):
    """

    filename: Unset | str = UNSET
    input_filename: Unset | str = UNSET
    file_download_url: Unset | str = UNSET
    resolution: Union[Unset, "VideoResolutionConstant"] = UNSET
    size: Unset | int = UNSET
    fps: Unset | float = UNSET
    width: Unset | int = UNSET
    height: Unset | int = UNSET
    created_at: Unset | datetime.datetime = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        filename = self.filename

        input_filename = self.input_filename

        file_download_url = self.file_download_url

        resolution: Unset | dict[str, Any] = UNSET
        if not isinstance(self.resolution, Unset):
            resolution = self.resolution.to_dict()

        size = self.size

        fps = self.fps

        width = self.width

        height = self.height

        created_at: Unset | str = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if filename is not UNSET:
            field_dict["filename"] = filename
        if input_filename is not UNSET:
            field_dict["inputFilename"] = input_filename
        if file_download_url is not UNSET:
            field_dict["fileDownloadUrl"] = file_download_url
        if resolution is not UNSET:
            field_dict["resolution"] = resolution
        if size is not UNSET:
            field_dict["size"] = size
        if fps is not UNSET:
            field_dict["fps"] = fps
        if width is not UNSET:
            field_dict["width"] = width
        if height is not UNSET:
            field_dict["height"] = height
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.video_resolution_constant import VideoResolutionConstant

        d = dict(src_dict)
        filename = d.pop("filename", UNSET)

        input_filename = d.pop("inputFilename", UNSET)

        file_download_url = d.pop("fileDownloadUrl", UNSET)

        _resolution = d.pop("resolution", UNSET)
        resolution: Unset | VideoResolutionConstant
        if isinstance(_resolution, Unset):
            resolution = UNSET
        else:
            resolution = VideoResolutionConstant.from_dict(_resolution)

        size = d.pop("size", UNSET)

        fps = d.pop("fps", UNSET)

        width = d.pop("width", UNSET)

        height = d.pop("height", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Unset | datetime.datetime
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        video_source = cls(
            filename=filename,
            input_filename=input_filename,
            file_download_url=file_download_url,
            resolution=resolution,
            size=size,
            fps=fps,
            width=width,
            height=height,
            created_at=created_at,
        )

        video_source.additional_properties = d
        return video_source

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from typing_extensions import Self

T = TypeVar("T", bound="UpdatePluginBodyType1")


@_attrs_define
class UpdatePluginBodyType1:
    """Attributes:
    path (str):
    """

    path: str

    def to_dict(self) -> dict[str, Any]:
        """Convert to dictionary."""

        path = self.path

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "path": path,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create from dictionary."""

        d = dict(src_dict)
        path = d.pop("path")

        update_plugin_body_type_1 = cls(path=path)

        return update_plugin_body_type_1



from enum import IntEnum


class FileStorage(IntEnum):
    """FileStorage enumeration."""

    VALUE_0 = 0
    VALUE_1 = 1

    def __str__(self) -> str:
        """Return string representation."""

        return str(self.value)



from http import HTTPStatus
from typing import Any

import httpx
from pydantic import ConfigDict, validate_call

from peertube import errors
from peertube.client import AuthenticatedClient, Client
from peertube.models.get_mirrored_videos_sort import GetMirroredVideosSort
from peertube.models.get_mirrored_videos_target import GetMirroredVideosTarget
from peertube.models.video_redundancy import VideoRedundancy
from peertube.types import UNSET, Response, Unset


def _get_kwargs(
    *,
    target: GetMirroredVideosTarget,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | GetMirroredVideosSort = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    json_target = target.value
    params["target"] = json_target

    params["start"] = start

    params["count"] = count
    json_sort: Unset | str = UNSET
    if not isinstance(sort, Unset):
        json_sort = sort.value

    params["sort"] = json_sort
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/api/v1/server/redundancy/videos",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> list["VideoRedundancy"] | None:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = VideoRedundancy.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[list["VideoRedundancy"]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


@validate_call(config=ConfigDict(arbitrary_types_allowed=True))
def sync_detailed(
    *,
    client: AuthenticatedClient,
    target: GetMirroredVideosTarget,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | GetMirroredVideosSort = UNSET,
) -> Response[list["VideoRedundancy"]]:
    """List videos being mirrored


    Args:
        target (GetMirroredVideosTarget): Parameter for target.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        sort (Union[Unset, GetMirroredVideosSort]): Sorting criteria for results.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[list['VideoRedundancy']]
    """

    kwargs = _get_kwargs(target=target, start=start, count=count, sort=sort)

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


@validate_call(config=ConfigDict(arbitrary_types_allowed=True))
def sync(
    *,
    client: AuthenticatedClient,
    target: GetMirroredVideosTarget,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | GetMirroredVideosSort = UNSET,
) -> list["VideoRedundancy"] | None:
    """List videos being mirrored


    Args:
        target (GetMirroredVideosTarget): Parameter for target.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        sort (Union[Unset, GetMirroredVideosSort]): Sorting criteria for results.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        list['VideoRedundancy']
    """

    return sync_detailed(
        client=client, target=target, start=start, count=count, sort=sort
    ).parsed


@validate_call(config=ConfigDict(arbitrary_types_allowed=True))
async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    target: GetMirroredVideosTarget,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | GetMirroredVideosSort = UNSET,
) -> Response[list["VideoRedundancy"]]:
    """List videos being mirrored


    Args:
        target (GetMirroredVideosTarget): Parameter for target.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        sort (Union[Unset, GetMirroredVideosSort]): Sorting criteria for results.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[list['VideoRedundancy']]
    """

    kwargs = _get_kwargs(target=target, start=start, count=count, sort=sort)

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


@validate_call(config=ConfigDict(arbitrary_types_allowed=True))
async def asyncio(
    *,
    client: AuthenticatedClient,
    target: GetMirroredVideosTarget,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | GetMirroredVideosSort = UNSET,
) -> list["VideoRedundancy"] | None:
    """List videos being mirrored


    Args:
        target (GetMirroredVideosTarget): Parameter for target.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        sort (Union[Unset, GetMirroredVideosSort]): Sorting criteria for results.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        list['VideoRedundancy']
    """

    return (
        await asyncio_detailed(
            client=client, target=target, start=start, count=count, sort=sort
        )
    ).parsed
